#
# spec file for package java
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{!?aarch64:%global aarch64 aarch64 arm64 armv8}
%{!?arm6:%global arm6 armv3l armv4b armv4l armv4tl armv5b armv5l armv5teb armv5tel armv5tejl armv6l armv6hl}
%global jit_arches %{ix86} x86_64 ppc64 ppc64le %{aarch64} %{arm} s390x
%global debug 0
%global buildoutputdir build
# Convert an absolute path to a relative path.  Each symbolic link is
# specified relative to the directory in which it is installed so that
# it will resolve properly within chrooted installations.
%global script 'use File::Spec; print File::Spec->abs2rel($ARGV[0], $ARGV[1])'
%global abs2rel perl -e %{script}
%global syslibdir       %{_libdir}
%global archname        %{name}
# Standard JPackage naming and versioning defines.
%global featurever      11
%global interimver      0
%global updatever       0
%global patchver        0
%global datever         2018-09-25
%global buildver        12
%global hg_project      jdk
%global hg_repository   jdk
%global hg_revision     3ab6ba9f94a9
%global icedtea_sound_version 1.0.1
%global java_atk_wrapper_version 0.33.2
# priority must be 6 digits in total
#%global priority        2105
# While this is an early technolog preview,
# assure nobody uses it by mistake.
# Thus the priority 0
%global priority        0
%global javaver         %{featurever}
# Standard JPackage directories and symbolic links.
%global sdklnk          java-%{javaver}-openjdk
%global archname        %{sdklnk}
%global jrelnk          jre-%{javaver}-openjdk
%global jrebindir       %{_jvmdir}/%{jrelnk}/bin
%global sdkdir          %{sdklnk}-%{javaver}
%global sdkbindir       %{_jvmdir}/%{sdklnk}/bin
# Prevent brp-java-repack-jars from being run.
%global __jar_repack 0
# cacert symlink
%global cacerts  %{_jvmdir}/%{sdkdir}/lib/security/cacerts
# real file made by update-ca-certificates
%global javacacerts %{_var}/lib/ca-certificates/java-cacerts
%global bootcycle 1
# turn zero on non jit arches by default
%ifnarch %{jit_arches}
%global _with_zero 1
%endif
%if %{debug}
%global debugbuild slowdebug
%else
%global debugbuild release
%endif
%if %{bootcycle}
%global imagesdir bootcycle-build/images
%global imagestarget bootcycle-images all
%else
%global imagesdir images
%global imagestarget all
%endif
# bnc#542545
# 32-bit versus 64-bit specific provides:
%ifarch %{ix86} ppc s390
%global bits 32
%endif
%ifarch x86_64 ia64 s390x
%global bits 64
%endif
%if 0%{?__isa_bits}
%global bits %{__isa_bits}
%endif
# Turn on/off some features depending on openSUSE version
%if 0%{?suse_version} > 1320
%global with_system_pcsc 1
%else
%global with_system_pcsc 0
%endif
%global with_pulseaudio 1
%bcond_with zero
%if ! %{with zero}
%ifarch x86_64
%global _with_aot 1
%endif
%endif
%bcond_with aot
%if ! %{with zero}
%global with_systemtap 1
%else
%global with_systemtap 0
%endif
%if %{with_systemtap}
%global tapsetroot      %{_datadir}/systemtap
%global tapsetdir %{tapsetroot}/tapset/%{_build_cpu}
%endif
%if %{with_systemtap}
# Where to install systemtap tapset (links)
# We would like these to be in a package specific subdir,
# but currently systemtap doesn't support that, so we have to
# use the root tapset dir for now. To distinquish between 64
# and 32 bit architectures we place the tapsets under the arch
# specific dir (note that systemtap will only pickup the tapset
# for the primary arch for now). Systemtap uses the machine name
# aka build_cpu as architecture specific directory name.
%global tapsetroot %{_datadir}/systemtap
%global tapsetdir %{tapsetroot}/tapset/%{_build_cpu}
%endif
Name:           java-%{featurever}-openjdk
Version:        %{featurever}.%{interimver}.%{updatever}.%{patchver}~%{buildver}
Release:        lp150.1.4
Summary:        OpenJDK %{featurever} Runtime Environment
License:        Apache-1.1 AND Apache-2.0 AND GPL-1.0-or-later AND GPL-2.0-only AND GPL-2.0-with-classpath-exception AND LGPL-2.0-only AND MPL-1.0 AND MPL-1.1 AND SUSE-Public-Domain AND W3C
Group:          Development/Languages/Java
Url:            http://openjdk.java.net/
# Sources from upstream OpenJDK project.
Source0:        http://hg.openjdk.java.net/%{hg_project}/%{hg_repository}/archive/%{hg_revision}.tar.bz2
# Accessibility support
Source8:        ftp://ftp.gnome.org/pub/GNOME/sources/java-atk-wrapper/0.33/java-atk-wrapper-%{java_atk_wrapper_version}.tar.xz
# Pulseaudio support
Source9:        http://icedtea.classpath.org/download/source/icedtea-sound-%{icedtea_sound_version}.tar.xz
# Systemtap tapsets. Zipped up to keep it small.
Source10:       systemtap-tapset.tar.xz
# Desktop files. Adapated from IcedTea.
Source11:       jconsole.desktop.in
# nss configuration file
Source13:       nss.cfg
# Ensure we aren't using the limited crypto policy
Source14:       TestCryptoLevel.java
# Ensure ECDSA is working
Source15:       TestECDSA.java
# Fresh config.guess and config.sub files
# wget -O config.guess 'http://git.savannah.gnu.org/gitweb/?p=config.git;a=blob_plain;f=config.guess;hb=HEAD'
Source100:      config.guess
# wget -O config.sub 'http://git.savannah.gnu.org/gitweb/?p=config.git;a=blob_plain;f=config.sub;hb=HEAD'
Source101:      config.sub
# RPM/distribution specific patches
Patch1:         icedtea-sound-1.0.1-jdk9.patch
Patch2:         icedtea-sound-soundproperties.patch
# Restrict access to java-atk-wrapper classes
Patch3:         java-atk-wrapper-security.patch
# RHBZ 808293
Patch4:         PStack-808293.patch
# Allow multiple initialization of PKCS11 libraries
Patch5:         multiple-pkcs11-library-init.patch
# Fix instantiation of VM on ZERO
Patch8:         zero-ranges.patch
# From icedtea: Increase default memory limits
Patch10:        memory-limits.patch
# Fix use of unintialized memory in adlc parser
Patch12:        adlc-parser.patch
# Fix: implicit-pointer-decl
Patch13:        implicit-pointer-decl.patch
#
Patch15:        system-pcsclite.patch
#
# OpenJDK specific patches
#
Patch100:       s390-java-opts.patch
Patch101:       s390-size_t.patch
#
Patch200:       ppc_stack_overflow_fix.patch
Patch201:       fix_armv6_build.patch
Patch202:       aarch64-infinite-loop.patch
#
Patch302:       disable-doclint-by-default.patch
Patch303:       alternative-tzdb_dat.patch
#
Patch400:       jaw-misc.patch
Patch401:       jaw-jdk10.patch
Patch800:       java11-improved-fonts.patch
BuildRequires:  alsa-lib-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bc
BuildRequires:  binutils
BuildRequires:  cups-devel
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  fontconfig
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  giflib-devel
BuildRequires:  gtk2-devel
BuildRequires:  java-ca-certificates
BuildRequires:  libX11-devel
BuildRequires:  libXi-devel
BuildRequires:  libXinerama-devel
BuildRequires:  libXt-devel
BuildRequires:  libXtst-devel
BuildRequires:  libjpeg-devel
BuildRequires:  liblcms2-devel
BuildRequires:  libpng-devel
BuildRequires:  libtool
BuildRequires:  libxslt
BuildRequires:  pkgconfig
BuildRequires:  unzip
BuildRequires:  update-desktop-files
BuildRequires:  xorg-x11-proto-devel
BuildRequires:  xprop
BuildRequires:  zip
BuildRequires:  pkgconfig(atk) >= 2.14.0
BuildRequires:  pkgconfig(atk-bridge-2.0)
BuildRequires:  pkgconfig(atspi-2) >= 2.14.0
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gdk-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.32.0
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
# Requires rest of java
Requires:       %{name}-headless = %{version}-%{release}
Requires:       fontconfig
# mozilla-nss has to be installed to prevent
# java.security.ProviderException: Could not initialize NSS
# ...
# java.io.FileNotFoundException: /usr/lib64/libnss3.so
#was bnc#634793
Requires:       mozilla-nss
Requires(post): file
Requires(post): java-ca-certificates
# Standard JPackage base provides.
Provides:       java = %{javaver}
Provides:       java-%{javaver} = %{version}-%{release}
Provides:       java-openjdk = %{version}-%{release}
Provides:       jre = %{javaver}
Provides:       jre-%{javaver} = %{version}-%{release}
Provides:       jre-%{javaver}-openjdk = %{version}-%{release}
Provides:       jre-openjdk = %{version}-%{release}
# Standard JPackage extensions provides.
Provides:       java-fonts = %{version}
# Required at least by fop
Provides:       java-%{bits} = %{javaver}
Provides:       java-%{javaver}-%{bits}
Provides:       java-openjdk-%{bits} = %{version}-%{release}
Provides:       jre-%{bits} = %{javaver}
Provides:       jre-%{javaver}-%{bits}
Provides:       jre-%{javaver}-openjdk-%{bits} = %{version}-%{release}
Provides:       jre-openjdk-%{bits} = %{version}-%{release}
Provides:       jre1.10.x
Provides:       jre1.3.x
Provides:       jre1.4.x
Provides:       jre1.5.x
Provides:       jre1.6.x
Provides:       jre1.7.x
Provides:       jre1.8.x
Provides:       jre1.9.x
%if %{bootcycle}
BuildRequires:  java-devel >= 9
BuildConflicts: java-devel >= 12
%else
BuildRequires:  %{name}-devel
%endif
# Zero-assembler build requirement.
%if %{with zero}
BuildRequires:  libffi-devel
%endif
%if %{with_systemtap}
BuildRequires:  systemtap-sdt-devel
%endif
# pulse audio requirements
%if %{with_pulseaudio}
BuildRequires:  libpulse-devel >= 0.9.11
BuildRequires:  pulseaudio >= 0.9.11
%endif
%if %{with_system_pcsc}
BuildRequires:  pcsc-lite-devel
%endif
%if %{with aot}
BuildRequires:  libelf-devel
%endif

%description
The OpenJDK %{featurever} runtime environment.

%package headless
Summary:        OpenJDK %{featurever} Runtime Environment
Group:          Development/Languages/Java
Requires:       jpackage-utils
# Post requires update-alternatives to install tool update-alternatives.
Requires(post): update-alternatives
# Postun requires update-alternatives to uninstall tool update-alternatives.
Requires(postun): update-alternatives
Recommends:     tzdata-java8
# Standard JPackage base provides.
Provides:       java-%{javaver}-headless = %{version}-%{release}
Provides:       java-headless = %{javaver}
Provides:       java-openjdk-headless = %{version}-%{release}
Provides:       jre-%{javaver}-headless = %{version}-%{release}
Provides:       jre-%{javaver}-openjdk-headless = %{version}-%{release}
Provides:       jre-headless = %{javaver}
Provides:       jre-openjdk-headless = %{version}-%{release}
# Standard JPackage extensions provides.
Provides:       jaas = %{version}
Provides:       java-sasl = %{version}
Provides:       jce = %{version}
Provides:       jdbc-stdext = 4.3
Provides:       jndi = %{version}
Provides:       jndi-cos = %{version}
Provides:       jndi-dns = %{version}
Provides:       jndi-ldap = %{version}
Provides:       jndi-rmi = %{version}
Provides:       jsse = %{version}

%description headless
The OpenJDK %{featurever} runtime environment without audio and video support.

%package devel
Summary:        OpenJDK %{featurever} Development Environment
# Require base package.
Group:          Development/Languages/Java
Requires:       %{name} = %{version}-%{release}
# Post requires update-alternatives to install tool update-alternatives.
Requires(post): update-alternatives
# Postun requires update-alternatives to uninstall tool update-alternatives.
Requires(postun): update-alternatives
# Standard JPackage devel provides.
Provides:       java-%{javaver}-devel = %{version}
Provides:       java-devel = %{javaver}
Provides:       java-devel-openjdk = %{version}
Provides:       java-sdk = %{javaver}
Provides:       java-sdk-%{javaver} = %{version}
Provides:       java-sdk-%{javaver}-openjdk = %{version}
Provides:       java-sdk-openjdk = %{version}

%description devel
The OpenJDK %{featurever} development tools.

%package jmods
Summary:        JMods for OpenJDK %{featurever}
Group:          Development/Languages/Java
Requires:       %{name}-devel = %{version}-%{release}

%description jmods
The JMods for OpenJDK %{featurever}.

%package demo
Summary:        OpenJDK %{featurever} Demos
Group:          Development/Languages/Java
Requires:       %{name} = %{version}-%{release}

%description demo
The OpenJDK %{featurever} demos.

%package src
Summary:        OpenJDK %{featurever} Source Bundle
Group:          Development/Languages/Java
Requires:       %{name} = %{version}-%{release}

%description src
The OpenJDK %{featurever} source bundle.

%package javadoc
Summary:        OpenJDK %{featurever} API Documentation
Group:          Development/Languages/Java
Requires:       jpackage-utils
# Post requires update-alternatives to install javadoc alternative.
Requires(post): update-alternatives
# Postun requires update-alternatives to uninstall javadoc alternative.
Requires(postun): update-alternatives
# Standard JPackage javadoc provides.
Provides:       java-%{javaver}-javadoc = %{version}-%{release}
Provides:       java-javadoc = %{version}-%{release}
BuildArch:      noarch

%description javadoc
The OpenJDK %{featurever} API documentation.

%package accessibility
Summary:        OpenJDK %{featurever} accessibility connector
Group:          Development/Languages/Java
Requires:       %{name} = %{version}-%{release}
Requires:       xprop

%description accessibility
Enables accessibility support in OpenJDK %{featurever} by using java-atk-wrapper. This allows
compatible at-spi2 based accessibility programs to work for AWT and Swing-based
programs.

Please note, the java-atk-wrapper is still in beta, and OpenJDK itself is still
being tuned to be working with accessibility features. There are known issues
with accessibility on, so please do not install this package unless you really
need to.

%prep
%setup -q -n %{hg_repository}-%{hg_revision}
%setup -q -D -n %{hg_repository}-%{hg_revision} -T -a 8
%setup -q -D -n %{hg_repository}-%{hg_revision} -T -a 9

# Replace config.sub and config.guess with fresh versions
cp %{SOURCE100} make/autoconf/build-aux/
cp %{SOURCE101} make/autoconf/build-aux/

# Remove libraries that are linked
rm -rvf src/java.base/share/native/libzip/zlib-*
find src/java.desktop/share/native/libjavajpeg ! -name imageioJPEG.c ! -name jpegdecoder.c -type f -delete
rm -rvf src/java.desktop/share/native/libsplashscreen/libpng
rm -rvf src/java.desktop/share/native/libsplashscreen/giflib
rm -rvf src/java.desktop/share/native/liblcms/cms*
rm -rvf src/java.desktop/share/native/liblcms/lcms2*

%patch1
%if %{with_pulseaudio}
%patch2 -p1
%endif

%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch8 -p1
%patch10 -p1
%patch12 -p1
%patch13 -p1

%if %{with_system_pcsc}
%patch15 -p1
%endif

# s390 build fixes

%ifarch s390
%patch100 -p1
%patch101 -p1
%endif

%patch200 -p1

%ifarch %{arm6}
%patch201 -p0
%endif

%patch202 -p1

%patch302 -p1
%patch303 -p1

%patch800 -p1

%patch400
%patch401

# Extract systemtap tapsets

%if %{with_systemtap}

tar -x -I xz -f %{SOURCE10}

for file in tapset/*.in; do

    OUTPUT_FILE=`echo $file | sed -e s:\.in$::g`
    sed -e s:@ABS_SERVER_LIBJVM_SO@:%{_jvmdir}/%{sdkdir}/lib/server/libjvm.so:g $file > $file.1
# TODO find out which architectures other than ix86 have a client vm

%ifarch %{ix86} %{arm6}
    sed -e s:@ABS_CLIENT_LIBJVM_SO@:%{_jvmdir}/%{sdkdir}/lib/client/libjvm.so:g $file.1 > $OUTPUT_FILE
%else
    sed -e '/@ABS_CLIENT_LIBJVM_SO@/d' $file.1 > $OUTPUT_FILE
%endif
    sed -i -e s:@ABS_JAVA_HOME_DIR@:%{_jvmdir}/%{sdkdir}:g $OUTPUT_FILE

done

%endif

# Prepare desktop files
for file in %{SOURCE11} %{SOURCE12} ; do
    OUTPUT_FILE=`basename $file | sed -e s:\.in$::g`
    sed -e s:@JAVA_HOME@:%{_jvmdir}/%{sdkdir}:g $file > $OUTPUT_FILE
    sed -i -e s:@VERSION@:%{javaver}.%{_arch}:g $OUTPUT_FILE
done

%build
# How many cpu's do we have?
export NUM_PROC=`%{_bindir}/getconf _NPROCESSORS_ONLN 2> /dev/null || :`
export NUM_PROC=${NUM_PROC:-1}

# Build OpenJDK.

%ifarch s390x sparc64 alpha ppc64 ppc64le %{aarch64}
export ARCH_DATA_MODEL=64
%endif

%ifarch alpha
export CFLAGS="$CFLAGS -mieee"
%endif

EXTRA_CFLAGS="-Wno-error -DIMPROVED_FONT_RENDERING"
EXTRA_CPP_FLAGS="-Wno-error -DIMPROVED_FONT_RENDERING"

%ifarch ppc64 ppc64le ppc
EXTRA_CFLAGS="$EXTRA_CFLAGS -fno-strict-aliasing"
%endif

%if 0%{?suse_version} >= 1330
EXTRA_CFLAGS="$EXTRA_CFLAGS -Wno-error -std=gnu++98 -fno-delete-null-pointer-checks -fno-lifetime-dse -fpermissive"
EXTRA_CPP_FLAGS="$EXTRA_CPP_FLAGS -Wno-error -std=gnu++98 -fno-delete-null-pointer-checks -fno-lifetime-dse"
%endif

mkdir -p %{buildoutputdir}

pushd %{buildoutputdir}

bash ../configure \
    --with-version-feature=%{featurever} \
    --with-version-interim=%{interimver} \
    --with-version-update=%{updatever} \
    --with-version-patch=%{patchver} \
    --with-version-date=%{datever} \
    --with-version-build=%{buildver} \
%if 0
    --with-version-pre="" \
%endif
    --with-version-opt="suse-%{release}-%{_arch}" \
    --disable-warnings-as-errors \
%if %{with zero}
    --with-jvm-variants=zero \
%else
%ifarch %{arm6}
    --with-jvm-variants=client \
%endif
%endif
%if %{with aot}
    --enable-aot \
%else
    --disable-aot \
%endif
    --disable-zip-debug-info \
    --disable-keep-packaged-modules \
    --with-debug-level=%{debugbuild} \
    --with-zlib=system \
    --with-libjpeg=system \
    --with-giflib=system \
    --with-libpng=system \
    --with-lcms=system \
%if %{with_system_pcsc}
    --with-pcsclite=system \
%endif
    --with-stdc++lib=dynamic \
%ifnarch %{arm}
    --with-num-cores="$NUM_PROC" \
%endif
%ifarch s390
    --with-boot-jdk-jvmargs="-Xms256M -Xmx768M" \
%endif
    --with-extra-cxxflags="$EXTRA_CPP_FLAGS" \
    --with-extra-cflags="$EXTRA_CFLAGS" \
    --disable-javac-server

# The combination of FULL_DEBUG_SYMBOLS=0 and ALT_OBJCOPY=/does_not_exist
# disables FDS for all build configs and reverts to pre-FDS make %{?_smp_mflags} logic.
# STRIP_POLICY=none says don't do any stripping. DEBUG_BINARIES=true says
# ignore all the other logic about which debug options and just do '-g'.

make \
    JAVAC_FLAGS=-g \
    LOG=trace \
    DEBUG_BINARIES=true \
    STRIP_POLICY=no_strip \
    POST_STRIP_CMD="" \
    WARNINGS_ARE_ERRORS="-Wno-error" \
    CFLAGS_WARNINGS_ARE_ERRORS="-Wno-error" \
    %{imagestarget} docs

# remove redundant *diz and *debuginfo files
find %{imagesdir}/jdk -iname '*.diz' -exec rm {} \;
find %{imagesdir}/jdk -iname '*.debuginfo' -exec rm {} \;

popd >& /dev/null

export JAVA_HOME=$(pwd)/%{buildoutputdir}/%{imagesdir}/jdk

# Copy tz.properties
echo "sun.zoneinfo.dir=%{_datadir}/javazi" >> $JAVA_HOME/conf/tz.properties

%if %{with_pulseaudio}
# Build the pulseaudio plugin
pushd icedtea-sound-%{icedtea_sound_version}
autoreconf --force --install
%configure \
    --with-jdk-home=$JAVA_HOME \
    --disable-docs
make %{?_smp_mflags}
cp icedtea-sound.jar $JAVA_HOME/../jmods/
cp build/native/libicedtea-sound.so $JAVA_HOME/lib/
popd
# Merge the icedtea-sound into the JDK
source $JAVA_HOME/release; export MODULES
$JAVA_HOME/bin/jlink --module-path $JAVA_HOME/../jmods --add-modules "icedtea.sound,${MODULES//\ /,}" --output $JAVA_HOME/../newjdk
cp -rf $JAVA_HOME/../newjdk/* $JAVA_HOME/
rm -rf $JAVA_HOME/../newjdk
%endif

# Build the accessibility plugin
pushd java-atk-wrapper-%{java_atk_wrapper_version}
autoreconf --force --install
rm wrapper/org/GNOME/Accessibility/AtkWrapper.java
%configure \
    --without-jdk-auto-detect \
    JDK_SRC=$JAVA_HOME
rm wrapper/org/GNOME/Accessibility/AtkWrapper.java
make %{?_smp_mflags}
cp wrapper/java-atk-wrapper.jar $JAVA_HOME/../jmods/
cp jni/src/.libs/libatk-wrapper.so $JAVA_HOME/lib/
popd
# Merge the java-atk-wrapper into the JDK
source $JAVA_HOME/release; export MODULES
$JAVA_HOME/bin/jlink --module-path $JAVA_HOME/../jmods --add-modules "atk.wrapper,${MODULES//\ /,}" --output $JAVA_HOME/../newjdk
cp -rf $JAVA_HOME/../newjdk/* $JAVA_HOME/
rm -rf $JAVA_HOME/../newjdk

# cacerts are generated in runtime in openSUSE
if [ -f %{buildoutputdir}/%{imagesdir}/jdk/lib/security/cacerts ]; then
        rm %{buildoutputdir}/%{imagesdir}/jdk/lib/security/cacerts
fi

# Check debug symbols are present and can identify code
SERVER_JVM="$JAVA_HOME/lib/server/libjvm.so"
if [ -f "$SERVER_JVM" ] ; then
  nm -aCl "$SERVER_JVM" | grep javaCalls.cpp
fi
CLIENT_JVM="$JAVA_HOME/lib/client/libjvm.so"
if [ -f "$CLIENT_JVM" ] ; then
  nm -aCl "$CLIENT_JVM" | grep javaCalls.cpp
fi
ZERO_JVM="$JAVA_HOME/lib/zero/libjvm.so"
if [ -f "$ZERO_JVM" ] ; then
  nm -aCl "$ZERO_JVM" | grep javaCalls.cpp
fi

# Check unlimited policy has been used
$JAVA_HOME/bin/javac -d . %{SOURCE14}
$JAVA_HOME/bin/java --add-opens java.base/javax.crypto=ALL-UNNAMED TestCryptoLevel

# Check ECC is working
$JAVA_HOME/bin/javac -d . %{SOURCE15}
#FIXME make it run after system NSS support?
$JAVA_HOME/bin/java $(echo $(basename %{SOURCE15})|sed "s|\.java||") || true

%install
export LANG=en_US.UTF-8
#bnc#530046
export STRIP_KEEP_SYMTAB=libjvm*
# skip /usr/lib/rpm/brp-check-bytecode-version:
export NO_BRP_CHECK_BYTECODE_VERSION=true

%if %{with_systemtap}
  # Install systemtap support files.
  install -dm 755 %{buildroot}%{_jvmdir}/%{sdkdir}/tapset
  cp -a tapset/*.stp %{buildroot}%{_jvmdir}/%{sdkdir}/tapset/
  install -d -m 755 %{buildroot}%{tapsetdir}
  pushd %{buildroot}%{tapsetdir}
    RELATIVE=$(%{abs2rel} %{_jvmdir}/%{sdkdir}/tapset %{tapsetdir})
    ln -sf $RELATIVE/*.stp .
  popd
%endif

pushd %{buildoutputdir}/%{imagesdir}/jdk

  # Install main files.
  install -d -m 755 %{buildroot}%{_jvmdir}/%{sdkdir}
  cp -a bin include lib conf release %{buildroot}%{_jvmdir}/%{sdkdir}

  # Install JCE policy symlinks.
  install -d -m 755 %{buildroot}%{_jvmprivdir}/%{archname}/jce/vanilla

  # Install versionless symlinks.
  pushd %{buildroot}%{_jvmdir}
    ln -sf %{sdkdir} %{jrelnk}
    ln -sf %{sdkdir} %{sdklnk}
  popd

  # Remove javaws man page
  rm -f man/man1/javaws*

  # Install man pages.
  install -d -m 755 %{buildroot}%{_mandir}/man1
  rm -f man/man1/javah*.1
  for manpage in man/man1/*
  do
    # Convert man pages to UTF8 encoding.
    iconv -f ISO_8859-1 -t UTF8 $manpage -o $manpage.tmp
    mv -f $manpage.tmp $manpage
    install -m 644 -p $manpage %{buildroot}%{_mandir}/man1/$(basename \
      $manpage .1)-%{sdklnk}.1
  done

  # Install demos and samples.
  cp -a demo %{buildroot}%{_jvmdir}/%{sdkdir}
  # enable short-circuit
  mkdir -p sample/rmi
  [ -f bin/java-rmi.cgi ] && mv bin/java-rmi.cgi sample/rmi
  cp -a sample %{buildroot}%{_jvmdir}/%{sdkdir}

popd

pushd %{buildoutputdir}/%{imagesdir}

  # Install jmods
  cp -a jmods %{buildroot}%{_jvmdir}/%{sdkdir}

popd

# Install nss.cfg
install -m 644 %{SOURCE13} %{buildroot}%{_jvmdir}/%{sdkdir}/lib/security/

# Install Javadoc documentation.
install -d -m 755 %{buildroot}%{_javadocdir}
cp -a %{buildoutputdir}/images/docs %{buildroot}%{_javadocdir}/%{sdklnk}

# Install icons and menu entries.
for s in 16 24 32 48 ; do
  install -D -p -m 644 \
    src/java.desktop/unix/classes/sun/awt/X11/java-icon${s}.png \
    %{buildroot}%{_datadir}/icons/hicolor/${s}x${s}/apps/java-%{javaver}.png
done

# Install desktop file.
install -d -m 0755 %{buildroot}%{_datadir}/{applications,pixmaps}
install -d -m 0755 %{buildroot}/%{_jvmdir}/%{sdkdir}/lib/desktop/
install -m 0644 jconsole.desktop %{buildroot}/%{_jvmdir}/%{sdkdir}/lib/desktop/
%suse_update_desktop_file %{buildroot}/%{_jvmdir}/%{sdkdir}/lib/desktop/jconsole.desktop

# Find demo directories.
find %{buildroot}%{_jvmdir}/%{sdkdir}/demo \
  %{buildroot}%{_jvmdir}/%{sdkdir}/sample -type d \
  | sed 's|'%{buildroot}'|%dir |' \
  > %{name}-demo.files

# FIXME: remove SONAME entries from demo DSOs.  See
# https://bugzilla.redhat.com/show_bug.cgi?id=436497

# Find non-documentation demo files.
find %{buildroot}%{_jvmdir}/%{sdkdir}/demo \
  %{buildroot}%{_jvmdir}/%{sdkdir}/sample \
  -type f -o -type l | sort \
  | grep -v README \
  | sed 's|'%{buildroot}'||' \
  >> %{name}-demo.files
# Find documentation demo files.
find %{buildroot}%{_jvmdir}/%{sdkdir}/demo \
  %{buildroot}%{_jvmdir}/%{sdkdir}/sample \
  -type f -o -type l | sort \
  | grep README \
  | sed 's|'%{buildroot}'||' \
  | sed 's|^|%doc |' \
  >> %{name}-demo.files

# Create a config file to  enable java-atk-wrapper
pushd %{buildroot}/%{_jvmdir}/%{sdkdir}/conf/
  echo "#Config file to  enable java-atk-wrapper" > accessibility.properties
  echo "" >> accessibility.properties
  echo "assistive_technologies=org.GNOME.Accessibility.AtkWrapper" >> accessibility.properties
  echo "" >> accessibility.properties
popd

# fdupes links the files from JDK to JRE, so it breaks a JRE
# use it carefully :))
%fdupes -s %{buildroot}/%{_jvmdir}/%{sdkdir}/
%fdupes -s %{buildroot}/%{_jvmdir}/%{sdkdir}/demo
%fdupes -s %{buildroot}%{_javadocdir}/%{sdklnk}

%post headless
ext=.gz
update-alternatives \
  --install %{_bindir}/java java %{jrebindir}/java %{priority} \
  --slave %{_jvmdir}/jre jre %{_jvmdir}/%{jrelnk} \
  --slave %{_bindir}/jjs jjs %{jrebindir}/jjs \
  --slave %{_bindir}/keytool keytool %{jrebindir}/keytool \
  --slave %{_bindir}/rmid rmid %{jrebindir}/rmid \
  --slave %{_bindir}/rmiregistry rmiregistry %{jrebindir}/rmiregistry \
  --slave %{_mandir}/man1/java.1$ext java.1$ext \
  %{_mandir}/man1/java-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jjs.1$ext jjs.1$ext \
  %{_mandir}/man1/jjs-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/keytool.1$ext keytool.1$ext \
  %{_mandir}/man1/keytool-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/rmid.1$ext rmid.1$ext \
  %{_mandir}/man1/rmid-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/rmiregistry.1$ext rmiregistry.1$ext \
  %{_mandir}/man1/rmiregistry-%{sdklnk}.1$ext

update-alternatives \
  --install %{_jvmdir}/jre-openjdk \
  jre_openjdk %{_jvmdir}/%{jrelnk} %{priority}
update-alternatives \
  --install %{_jvmdir}/jre-%{javaver} \
  jre_%{javaver} %{_jvmdir}/%{jrelnk} %{priority}

%postun headless
if [ $1 -eq 0 ]
then
  if test -f /proc/sys/fs/binfmt_misc/jarexec
  then
    echo '-1' > /proc/sys/fs/binfmt_misc/jarexec
  fi
  update-alternatives --remove java %{jrebindir}/java
  update-alternatives --remove jre_openjdk %{_jvmdir}/%{jrelnk}
  update-alternatives --remove jre_%{javaver} %{_jvmdir}/%{jrelnk}
fi

%posttrans headless
# bnc#781690#c11: don't trust user defined JAVA_HOME and use the current VM
# XXX: this might conflict between various versions of openjdk
export JAVA_HOME=%{_jvmdir}/%{jrelnk}

# check if the java-cacerts is a valid keystore (bnc#781690)
if [ X"`%{_bindir}/file --mime-type -b %{javacacerts}`" \
    != "Xapplication/x-java-keystore;" ]; then
%if 0%{?suse_version} <= 1310
    # workaround for bnc#847952 - pre 13.1 keyring.jar attempts to load invalid keystore and fail on it
    rm -f "%{javacacerts}"
%endif
    %{_sbindir}/update-ca-certificates
fi

# remove the default empty cacert file, if it's installed
if [ 0`stat -c "%{s}" %{cacerts} 2>/dev/null` = "032" ] ; then
    rm -f %{cacerts}
fi

# if cacerts does exists, neither does not contain/point to a
# valid keystore (bnc#781690) ...
if [ X"`%{_bindir}/file --mime-type -b -L %{cacerts}`" \
    != "Xapplication/x-java-keystore;" ]; then
    # bnc#727223
    rm -f %{cacerts}
    ln -s %{javacacerts} %{cacerts}
fi

%post devel
ext=.gz
update-alternatives \
  --install %{_bindir}/javac javac %{sdkbindir}/javac %{priority} \
  --slave %{_jvmdir}/java java_sdk %{_jvmdir}/%{sdklnk} \
  --slave %{_bindir}/appletviewer appletviewer %{sdkbindir}/appletviewer \
%if %{with aot}
  --slave %{_bindir}/jaotc jaotc %{sdkbindir}/jaotc \
%endif
  --slave %{_bindir}/jar jar %{sdkbindir}/jar \
  --slave %{_bindir}/jarsigner jarsigner %{sdkbindir}/jarsigner \
  --slave %{_bindir}/javadoc javadoc %{sdkbindir}/javadoc \
  --slave %{_bindir}/javap javap %{sdkbindir}/javap \
  --slave %{_bindir}/jcmd jcmd %{sdkbindir}/jcmd \
  --slave %{_bindir}/jconsole jconsole %{sdkbindir}/jconsole \
  --slave %{_bindir}/jdb jdb %{sdkbindir}/jdb \
  --slave %{_bindir}/jdeprscan jdeprscan %{sdkbindir}/jdeprscan \
  --slave %{_bindir}/jdeps jdeps %{sdkbindir}/jdeps \
%if ! %{with zero}
  --slave %{_bindir}/jhsdb jhsdb %{sdkbindir}/jhsdb \
%endif
  --slave %{_bindir}/jimage jimage %{sdkbindir}/jimage \
  --slave %{_bindir}/jinfo jinfo %{sdkbindir}/jinfo \
  --slave %{_bindir}/jlink jlink %{sdkbindir}/jlink \
  --slave %{_bindir}/jmap jmap %{sdkbindir}/jmap \
  --slave %{_bindir}/jmod jmod %{sdkbindir}/jmod \
  --slave %{_bindir}/jps jps %{sdkbindir}/jps \
  --slave %{_bindir}/jrunscript jrunscript %{sdkbindir}/jrunscript \
  --slave %{_bindir}/jshell jshell %{sdkbindir}/jshell \
  --slave %{_bindir}/jstack jstack %{sdkbindir}/jstack \
  --slave %{_bindir}/jstat jstat %{sdkbindir}/jstat \
  --slave %{_bindir}/jstatd jstatd %{sdkbindir}/jstatd \
  --slave %{_bindir}/pack200 pack200 %{sdkbindir}/pack200 \
  --slave %{_bindir}/rmic rmic %{sdkbindir}/rmic \
  --slave %{_bindir}/serialver serialver %{sdkbindir}/serialver \
  --slave %{_bindir}/unpack200 unpack200 %{sdkbindir}/unpack200 \
  --slave %{_mandir}/man1/appletviewer.1$ext appletviewer.1$ext \
  %{_mandir}/man1/appletviewer-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jar.1$ext jar.1$ext \
  %{_mandir}/man1/jar-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jarsigner.1$ext jarsigner.1$ext \
  %{_mandir}/man1/jarsigner-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/javac.1$ext javac.1$ext \
  %{_mandir}/man1/javac-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/javadoc.1$ext javadoc.1$ext \
  %{_mandir}/man1/javadoc-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/javap.1$ext javap.1$ext \
  %{_mandir}/man1/javap-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jcmd.1$ext jcmd.1$ext \
  %{_mandir}/man1/jcmd-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jconsole.1$ext jconsole.1$ext \
  %{_mandir}/man1/jconsole-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jdb.1$ext jdb.1$ext \
  %{_mandir}/man1/jdb-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jdeps.1$ext jdeps.1$ext \
  %{_mandir}/man1/jdeps-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jinfo.1$ext jinfo.1$ext \
  %{_mandir}/man1/jinfo-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jmap.1$ext jmap.1$ext \
  %{_mandir}/man1/jmap-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jps.1$ext jps.1$ext \
  %{_mandir}/man1/jps-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jrunscript.1$ext jrunscript.1$ext \
  %{_mandir}/man1/jrunscript-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jstack.1$ext jstack.1$ext \
  %{_mandir}/man1/jstack-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jstat.1$ext jstat.1$ext \
  %{_mandir}/man1/jstat-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jstatd.1$ext jstatd.1$ext \
  %{_mandir}/man1/jstatd-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/pack200.1$ext pack200.1$ext \
  %{_mandir}/man1/pack200-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/rmic.1$ext rmic.1$ext \
  %{_mandir}/man1/rmic-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/serialver.1$ext serialver.1$ext \
  %{_mandir}/man1/serialver-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/unpack200.1$ext unpack200.1$ext \
  %{_mandir}/man1/unpack200-%{sdklnk}.1$ext \
  --slave %{_datadir}/applications/jconsole.desktop jconsole.desktop \
  %{_jvmdir}/%{sdkdir}/lib/desktop/jconsole.desktop

update-alternatives \
  --install %{_jvmdir}/java-openjdk \
  java_sdk_openjdk %{_jvmdir}/%{sdklnk} %{priority}
update-alternatives \
  --install %{_jvmdir}/java-%{javaver} \
  java_sdk_%{javaver} %{_jvmdir}/%{sdklnk} %{priority}

%postun devel
if [ $1 -eq 0 ]
then
  update-alternatives --remove javac %{sdkbindir}/javac
  update-alternatives --remove java_sdk_openjdk %{_jvmdir}/%{sdklnk}
  update-alternatives --remove java_sdk_%{javaver} %{_jvmdir}/%{sdklnk}
fi

%post javadoc
update-alternatives \
  --install %{_javadocdir}/java javadocdir %{_javadocdir}/%{sdklnk}/api \
  %{priority}

%postun javadoc
if [ $1 -eq 0 ]
then
  update-alternatives --remove javadocdir %{_javadocdir}/%{sdklnk}/api
fi

%files
%dir %{_jvmdir}/%{sdkdir}/lib
%{_jvmdir}/%{sdkdir}/lib/libawt_xawt.so
%if %{with_pulseaudio}
%{_jvmdir}/%{sdkdir}/lib/libicedtea-sound.so
%endif
%{_jvmdir}/%{sdkdir}/lib/libjawt.so
%{_jvmdir}/%{sdkdir}/lib/libsplashscreen.so
%dir %{_datadir}/icons/hicolor
%{_datadir}/icons/hicolor/*x*/apps/java-%{javaver}.png

%files headless
%dir %{_jvmdir}
%dir %{_jvmdir}/%{sdkdir}/
%dir %{_jvmdir}/%{sdkdir}/bin
%dir %{_jvmdir}/%{sdkdir}/lib
%dir %{_jvmdir}/%{sdkdir}/lib/jli
%ifarch %{arm6}
%dir %{_jvmdir}/%{sdkdir}/lib/client
%else
%dir %{_jvmdir}/%{sdkdir}/lib/server
%endif
%dir %{_jvmdir}/%{sdkdir}/lib/desktop
%dir %{_jvmdir}/%{sdkdir}/lib/security

%dir %{_jvmdir}/%{sdkdir}/conf
%dir %{_jvmdir}/%{sdkdir}/conf/security
%dir %{_jvmdir}/%{sdkdir}/conf/security/policy
%dir %{_jvmdir}/%{sdkdir}/conf/security/policy/unlimited
%dir %{_jvmdir}/%{sdkdir}/conf/security/policy/limited
%dir %{_jvmdir}/%{sdkdir}/conf/management

%dir %{_jvmdir}/%{sdkdir}
%{_jvmdir}/%{jrelnk}
%{_jvmprivdir}/*

%{_jvmdir}/%{sdkdir}/bin/java
%{_jvmdir}/%{sdkdir}/bin/jjs
%{_jvmdir}/%{sdkdir}/bin/keytool
%{_jvmdir}/%{sdkdir}/bin/rmid
%{_jvmdir}/%{sdkdir}/bin/rmiregistry
%{_jvmdir}/%{sdkdir}/conf/logging.properties
%{_jvmdir}/%{sdkdir}/conf/management/jmxremote.access
%{_jvmdir}/%{sdkdir}/conf/management/jmxremote.password.template
%{_jvmdir}/%{sdkdir}/conf/management/management.properties
%{_jvmdir}/%{sdkdir}/conf/net.properties
%{_jvmdir}/%{sdkdir}/conf/security/java.policy
%{_jvmdir}/%{sdkdir}/conf/security/java.security
%{_jvmdir}/%{sdkdir}/conf/security/policy/limited/default_local.policy
%{_jvmdir}/%{sdkdir}/conf/security/policy/limited/default_US_export.policy
%{_jvmdir}/%{sdkdir}/conf/security/policy/limited/exempt_local.policy
%{_jvmdir}/%{sdkdir}/conf/security/policy/README.txt
%{_jvmdir}/%{sdkdir}/conf/security/policy/unlimited/default_local.policy
%{_jvmdir}/%{sdkdir}/conf/security/policy/unlimited/default_US_export.policy
%{_jvmdir}/%{sdkdir}/conf/sound.properties
%{_jvmdir}/%{sdkdir}/conf/tz.properties
%if ! %{with zero}
%{_jvmdir}/%{sdkdir}/lib/classlist
%endif
%{_jvmdir}/%{sdkdir}/lib/desktop/jconsole.desktop
%{_jvmdir}/%{sdkdir}/lib/jexec
%{_jvmdir}/%{sdkdir}/lib/jli/libjli.so
%{_jvmdir}/%{sdkdir}/lib/jrt-fs.jar
%{_jvmdir}/%{sdkdir}/lib/jvm.cfg
%{_jvmdir}/%{sdkdir}/lib/libawt_headless.so
%{_jvmdir}/%{sdkdir}/lib/libawt.so
%{_jvmdir}/%{sdkdir}/lib/libdt_socket.so
%{_jvmdir}/%{sdkdir}/lib/libextnet.so
%{_jvmdir}/%{sdkdir}/lib/libfontmanager.so
%{_jvmdir}/%{sdkdir}/lib/libinstrument.so
%{_jvmdir}/%{sdkdir}/lib/libj2gss.so
%{_jvmdir}/%{sdkdir}/lib/libj2pcsc.so
%{_jvmdir}/%{sdkdir}/lib/libj2pkcs11.so
%{_jvmdir}/%{sdkdir}/lib/libjaas.so
%{_jvmdir}/%{sdkdir}/lib/libjavajpeg.so
%{_jvmdir}/%{sdkdir}/lib/libjava.so
%{_jvmdir}/%{sdkdir}/lib/libjdwp.so
%{_jvmdir}/%{sdkdir}/lib/libjimage.so
%{_jvmdir}/%{sdkdir}/lib/libjsig.so
%{_jvmdir}/%{sdkdir}/lib/libjsound.so
%{_jvmdir}/%{sdkdir}/lib/liblcms.so
%{_jvmdir}/%{sdkdir}/lib/libmanagement_agent.so
%{_jvmdir}/%{sdkdir}/lib/libmanagement_ext.so
%{_jvmdir}/%{sdkdir}/lib/libmanagement.so
%{_jvmdir}/%{sdkdir}/lib/libmlib_image.so
%{_jvmdir}/%{sdkdir}/lib/libnet.so
%{_jvmdir}/%{sdkdir}/lib/libnio.so
%{_jvmdir}/%{sdkdir}/lib/libprefs.so
%{_jvmdir}/%{sdkdir}/lib/librmi.so
%{_jvmdir}/%{sdkdir}/lib/libsctp.so
%{_jvmdir}/%{sdkdir}/lib/libsunec.so
%{_jvmdir}/%{sdkdir}/lib/libunpack.so
%{_jvmdir}/%{sdkdir}/lib/libverify.so
%{_jvmdir}/%{sdkdir}/lib/libzip.so
%{_jvmdir}/%{sdkdir}/lib/modules
%{_jvmdir}/%{sdkdir}/lib/psfontj2d.properties
%{_jvmdir}/%{sdkdir}/lib/psfont.properties.ja
%{_jvmdir}/%{sdkdir}/lib/tzdb.dat
%{_jvmdir}/%{sdkdir}/lib/*/libjsig.so
%{_jvmdir}/%{sdkdir}/lib/*/libjvm.so
%{_jvmdir}/%{sdkdir}/lib/*/Xusage.txt

%config(noreplace) %{_jvmdir}/%{sdkdir}/lib/security/blacklisted.certs
%config(noreplace) %{_jvmdir}/%{sdkdir}/lib/security/nss.cfg
%{_jvmdir}/%{sdkdir}/lib/security/default.policy

%{_mandir}/man1/java-%{sdklnk}.1*
%{_mandir}/man1/jjs-%{sdklnk}.1*
%{_mandir}/man1/keytool-%{sdklnk}.1*
%{_mandir}/man1/rmid-%{sdklnk}.1*
%{_mandir}/man1/rmiregistry-%{sdklnk}.1*

%files devel
%dir %{_jvmdir}/%{sdkdir}/bin
%dir %{_jvmdir}/%{sdkdir}/include
%dir %{_jvmdir}/%{sdkdir}/lib

%if %{with_systemtap}
%dir %{_jvmdir}/%{sdkdir}/tapset
%endif
%{_jvmdir}/%{sdkdir}/bin/appletviewer
%if %{with aot}
%{_jvmdir}/%{sdkdir}/bin/jaotc
%endif
%{_jvmdir}/%{sdkdir}/bin/jar
%{_jvmdir}/%{sdkdir}/bin/jarsigner
%{_jvmdir}/%{sdkdir}/bin/javac
%{_jvmdir}/%{sdkdir}/bin/javadoc
%{_jvmdir}/%{sdkdir}/bin/javap
%{_jvmdir}/%{sdkdir}/bin/jcmd
%{_jvmdir}/%{sdkdir}/bin/jconsole
%{_jvmdir}/%{sdkdir}/bin/jdb
%{_jvmdir}/%{sdkdir}/bin/jdeprscan
%{_jvmdir}/%{sdkdir}/bin/jdeps
%if ! %{with zero}
%{_jvmdir}/%{sdkdir}/bin/jhsdb
%endif
%{_jvmdir}/%{sdkdir}/bin/jimage
%{_jvmdir}/%{sdkdir}/bin/jinfo
%{_jvmdir}/%{sdkdir}/bin/jlink
%{_jvmdir}/%{sdkdir}/bin/jmap
%{_jvmdir}/%{sdkdir}/bin/jmod
%{_jvmdir}/%{sdkdir}/bin/jps
%{_jvmdir}/%{sdkdir}/bin/jrunscript
%{_jvmdir}/%{sdkdir}/bin/jshell
%{_jvmdir}/%{sdkdir}/bin/jstack
%{_jvmdir}/%{sdkdir}/bin/jstat
%{_jvmdir}/%{sdkdir}/bin/jstatd
%{_jvmdir}/%{sdkdir}/bin/pack200
%{_jvmdir}/%{sdkdir}/bin/rmic
%{_jvmdir}/%{sdkdir}/bin/serialver
%{_jvmdir}/%{sdkdir}/bin/unpack200
%{_jvmdir}/%{sdkdir}/include/classfile_constants.h
%{_jvmdir}/%{sdkdir}/include/jawt.h
%{_jvmdir}/%{sdkdir}/include/jawt_md.h
%{_jvmdir}/%{sdkdir}/include/jdwpTransport.h
%{_jvmdir}/%{sdkdir}/include/jni.h
%{_jvmdir}/%{sdkdir}/include/jni_md.h
%{_jvmdir}/%{sdkdir}/include/jvmticmlr.h
%{_jvmdir}/%{sdkdir}/include/jvmti.h
%{_jvmdir}/%{sdkdir}/lib/ct.sym
%{_jvmdir}/%{sdkdir}/lib/libattach.so
%if ! %{with zero}
%{_jvmdir}/%{sdkdir}/lib/libsaproc.so
%endif

%if %{with_systemtap}
%{_jvmdir}/%{sdkdir}/tapset/*.stp
%endif
%{_jvmdir}/%{sdklnk}
%{_mandir}/man1/appletviewer-%{sdklnk}.1*
%{_mandir}/man1/jar-%{sdklnk}.1*
%{_mandir}/man1/jarsigner-%{sdklnk}.1*
%{_mandir}/man1/javac-%{sdklnk}.1*
%{_mandir}/man1/javadoc-%{sdklnk}.1*
%{_mandir}/man1/javap-%{sdklnk}.1*
%{_mandir}/man1/jcmd-%{sdklnk}.1*
%{_mandir}/man1/jconsole-%{sdklnk}.1*
%{_mandir}/man1/jdb-%{sdklnk}.1*
%{_mandir}/man1/jdeps-%{sdklnk}.1*
%{_mandir}/man1/jinfo-%{sdklnk}.1*
%{_mandir}/man1/jmap-%{sdklnk}.1*
%{_mandir}/man1/jps-%{sdklnk}.1*
%{_mandir}/man1/jrunscript-%{sdklnk}.1*
%{_mandir}/man1/jstack-%{sdklnk}.1*
%{_mandir}/man1/jstat-%{sdklnk}.1*
%{_mandir}/man1/jstatd-%{sdklnk}.1*
%{_mandir}/man1/pack200-%{sdklnk}.1*
%{_mandir}/man1/rmic-%{sdklnk}.1*
%{_mandir}/man1/serialver-%{sdklnk}.1*
%{_mandir}/man1/unpack200-%{sdklnk}.1*

%if %{with_systemtap}
%{tapsetroot}
%endif

%files jmods
%dir %{_jvmdir}/%{sdkdir}/jmods
%{_jvmdir}/%{sdkdir}/release
%{_jvmdir}/%{sdkdir}/jmods/*.jmod
%if %{with_pulseaudio}
%{_jvmdir}/%{sdkdir}/jmods/icedtea-sound.jar
%endif
%{_jvmdir}/%{sdkdir}/jmods/java-atk-wrapper.jar

%files demo -f %{name}-demo.files

%files src
%{_jvmdir}/%{sdkdir}/lib/src.zip

%files javadoc
%dir %{_javadocdir}
%dir %{_javadocdir}/%{sdklnk}
%{_javadocdir}/%{sdklnk}/*

%files accessibility
%config(noreplace) %{_jvmdir}/%{sdkdir}/conf/accessibility.properties
%{_jvmdir}/%{sdkdir}/lib/libatk-wrapper.so

%changelog
* Tue May  8 2018 fstrba@suse.com
- Added patch:
  * aarch64-infinite-loop.patch
    + Fix inifinite loop in aarch64 build
* Mon May  7 2018 fstrba@suse.com
- Update to upstream tag jdk-11+11
  * Fixes:
    + S6672778: G1 should trim task queues more aggressively during
    evacuation pauses
    + S8154204: [TESTBUG] Update DefaultUseWithClient test to
    handle client-less builds
    + S8174994: SA: clhsdb printmdo throws WrongTypeException when
    attached to a process with CDS
    + S8179071: Month value is inconsistent between CLDR and Java
    in some locales
    + S8179887: Build failure with glibc >= 2.24: error: 'int
    readdir_r(DIR*, dirent*, dirent**)' is deprecated
    + S8181157: CLDR Timezone name fallback implementation
    + S8182731: Odd handling of -XX:-UseAppCDS and
  - XX:SharedArchiveFile.
    + S8191471: Elastic TLABs for G1
    + S8191798: redo nested ThreadsListHandle to drop Threads_lock
    + S8193213: Make the UseAppCDS option obsolete.
    + S8197959: [TESTBUG] Some (App)CDS tests require modification
    due to the removal of the Java EE and CORBA modules
    + S8197960: [TESTBUG] remove/modify runtime tests which use
    java ee or corba modules
    + S8199375: [TESTBUG] Open source vm testbase monitoring tests
    + S8199643: [TESTBUG] Open source common VM testbase code
    + S8200167: Validate more special case invocations
    + S8200235: Generalize jniFastGetField jobject/jweak resolve
    + S8200466: Revisit the setting of _transitive_interfaces in
    InstanceKlass
    + S8200478: For boxing conversion javac uses Long.valueOf which
    does not guarantee caching according to its javadoc
    + S8201367: assert(current != first_mem) failed: corrupted
    memory graph in superword code
    + S8201509: Zero: S390 31bit atomic_copy64 inline assembler is
    wrong
    + S8201542: Remove unused _gc_timer field in GCMemoryManager
    + S8201543: Modularize C1 GC barriers
    + S8201545: InetAddress.getByName/getAllByName should clarify
    empty String behavior
    + S8201622: Reduce unnecessary Package.complete() calls in
    javadoc
    + S8201634: Random seedUniquifier uses incorrect LCG
    + S8201650: Move iteration order randomization of unmodifiable
    Set and Map to iterators
    + S8201786: Modularize interpreter GC barriers: leftovers for
    ARM32
    + S8201817: Taglet.init should be called with the "primary"
    doclet
    + S8202082: Remove explicit CMS checks in
    CardTableBarrierSetAssembler
    + S8202105: Console echo is disabled when exiting jshell
    + S8202130: [TESTBUG] Some appcds regression test cases fail
    with "Error: VM option 'PrintSystemDictionaryAtExit' is
    notproduct and is available only in debug version of VM"
    + S8202140: TLAB logging is not correct for G1
    + S8202150: [REDO] Split globals.hpp to factor out the Flag
    class
    + S8202179: Compilation fails with assert(n->is_expensive())
    failed: expensive nodes with non-null control here only
    + S8202186: AArch64: Debug build VM crashes with
    PrintC1Statistics option
    + S8202200: set INCLUDE_SA to false on s390x by default
    + S8202204: Rename hotspot runtime jtreg constantPool
    ConstantPool directories
    + S8202230: Provide accessors for JNIHandles storage objects
    + S8202261: (fc) FileChannel.map and RandomAccessFile.setLength
    should not preallocate space
    + S8202273: [AOT] Graal does not support the CMS collector
    + S8202284: FileChannel and FileOutpuStream variants of
    AtomicAppend should fail silently on macOS >= 10.13
    + S8202324: Avoid loading FileInput-/OutputStream$AltFinalizer
    + S8202325: [aix] disable warnings-as-errors by default
    + S8202330: Add Unreferenced{FOS,FIS,RAF}ClosesFd to problem
    list
    + S8202334: Update javax.lang.model.util visitors for 11
    + S8202364: Add GCConfig::hs_err_name() to avoid GC-specific
    code in error reporting
    + S8202366: Add macro for common loop in GCConfig
    + S8202367: AIX build broken after JDK-8201543
    + S8202372: Diagnostic with incorrect line info generated when
    compiling lambda expression
    + S8202373: Forcing eager initialization of CHM$ReservationNode
    avoids deoptimization
    + S8202379: ARM32 is broken after JDK-8201543 (Modularize C1 GC
    barriers)
    + S8202381: (Solaris) SIGBUS in # V [libjvm.so+0xcee494]
    jni_GetIntField+0x224
    + S8202382: Filter docs modules
    + S8202383: Custom extensions for jvmti doc
    + S8202397: Typo in X-Buffer javadoc
    + S8202398: Optimize Arrays.deepHashCode
    + S8202399: [C1] LIRGenerator::do_CheckCast needs to exclude
    is_invokespecial_receiver_check() when using PatchAlot
    + S8202417: [TESTBUG] Broken hard-coded dependency in
    serviceability/sa/ClhsdbJhisto.java
    + S8202418: Remove explicit CMS checks in
    CardTableBarrierSetAssembler: ARM32 leftovers
    + S8202419: Avoid creating Permission constants early
    + S8202423: Small HTTP Client refresh
    + S8202425: [s390] C2: Wrong unsigned comparison with 0
    + S8202452: Delete test files missed from commit for
    8193213 & 8182731.
    + S8202484: Unused field in TimeZone
    + S8202505: ctw2 tasks are timing out in hs-tier3
    + S8202507: Remove IO and NIO AtomicAppend tests from problem
    list
    + S8202520: JShell tests: move intermittently failing tests to
    tier2
* Mon May  7 2018 guillaume.gardet@opensuse.org
- Remove armv6 and armv7 overwrite conditions in _constraints to
  avoid OOM errors
* Fri Apr 27 2018 fstrba@suse.com
- Update to upstream tag jdk-11+11
  * Fixes:
    + S6341887: java.util.zip: Add ByteBuffer methods to
    Inflater/Deflater
    + S6805750: Improve handling of Attributes.Name
    + S8025091: VisibleMemberMap.java possible performance
    improvements
    + S8081519: Split globals.hpp to factor out the Flag class
    + S8144806: sun/security/tools/keytool/standard.sh fails
    intermittently at deleting x.jks
    + S8154528: Reclaim regions emptied by marking in Remark pause
    + S8157543: java/nio/channels/Selector/SelectAndCancel.java
    fails intermittently
    + S8161991: java/nio/channels/AsynchronousSocketChannel/Basic.java
    failed due to RuntimeException: WritePendingException expected
    + S8171404: java/nio/channels/AsynchronousSocketChannel/Basic.java
    failed with "AsynchronousCloseException expected"
    + S8178105: Switch mark bitmaps during Remark
    + S8178825: unused variable threadObj in jvmci_counters_include
    + S8184693: add Pattern.isEmpty
    + S8187490: HotSpotGraalMBean should be moved to Graal
    management module
    + S8187496: Possible memory leak in
    java.apple.security.KeychainStore.addItemToKeychain
    + S8188105: Make -Xshare:auto the default for server VM
    + S8190227: Forward port 8188880 to JDK10CPU
    + S8192789: Avoid using AtomicReference in
    sun.security.provider.PolicyFile
    + S8193524: Redefining a method that removes use of 1 or more
    lambda expressions causes the JVM to hang
    + S8196071: Change G1 Full GC heap and thread sizing ergonomics
    + S8196325: GarbageCollectionNotificationInfo has same
    information for before and after
    + S8196433: use the new error diagnostic approach at javac.Main
    + S8196540: [Testbug] java/security/AccessController/
    /DoPrivAccompliceTest.java doesn't handle unrelated warnings
    + S8198756: Lazy allocation of compiler threads
    + S8198793: Add launcher support for preview features
    + S8198816: AbstractScriptEngine.getScriptContext creation of
    SimpleScriptContext is inefficient
    + S8198890: The standard doclet incorrectly produces wrong
    method signatures in certain cases.
    + S8199193: jshell tool: Add support for preview features
    + S8199519: Several GC tests fails with:
    java.lang.NumberFormatException: Unparseable number: "-"
    + S8199755: Update Graal
    + S8200101: sun/security/krb5/auto/Renewal.java fails
    intermittently
    + S8200196: [Graal] implement Object.notify/notifyAll intrinsics
    + S8200303: C2 should leverage profiling for
    lookupswitch/tableswitch
    + S8200426: Make G1 code use _g1h members
    + S8200450: Root cause analysis for JDK-8200366
    + S8200477: Integer dot product no longer autovectorised
    + S8200555: OopHandle should use Access API
    + S8200556: AArch64: assertion failure in slowdebug builds
    + S8200723: Suppress rs_length and predicted_cards sampling
    during mixed gcs
    + S8200730: Fix debug=gc+phases time tracking in Remark and
    Cleanup
    + S8201172: Parallelize Remset Tracking Update Before Rebuild
    phase
    + S8201226: missing JNIEXPORT / JNICALL at some places in
    function declarations/implementations
    + S8201259: Fix warning with VS2017 in jdk.pack
    + S8201281: Truncated error message with Incompatible : null
    + S8201315: (se) Allow SelectableChannel.register to be invoked
    while selection operation is in progress
    + S8201368: IfNode::fold_compares() may lead to incorrect
    execution
    + S8201369: Inet4AddressImpl_getLocalHostName reverse lookup on
    Solaris only
    + S8201466: Nashorn: defineProperty setters/getters on
    prototype object ignored with numeric property names
    + S8201487: Do not rebalance reference processing queues if not
    doing parallel reference processing
    + S8201490: Improve concurrent mark keep alive closure
    performance
    + S8201505: Use WeakHandle for ProtectionDomainCacheTable and
    ResolvedMethodTable
    + S8201510: Merge TwoStacksPlainSocketImpl into
    DualStackPlainSocketImpl [win]
    + S8201520: AsynchronousSocketChannel/Basic.java timeout
    intermitently
    + S8201527: Bump default value of G1RefProcDrainInterval
    + S8201536: configure fails compiler check due to bad -m32 flag
    + S8201537: Remove is_alive closure from
    Klass::is_loader_alive()
    + S8201540: [AIX] Extend the set of supported charsets in
    java.base
    + S8201556: Disallow reading oops in ClassLoaderData if
    unloading
    + S8201596: java.lang.ref.Reference processing total time
    logging broken
    + S8201597: AArch64: Update relocs for CompiledDirectStaticCall
    + S8201616: Hotspot crashes on linux-sparc after 8189941
    + S8201646: Introduce ReferenceDiscoverer interface
    + S8201647: Make initial clearing of CHeapBitMap optional
    + S8201649: Remove dubious call_jio_print in ostream.cpp
    + S8201766: Mark TimSortStackSize2.java as intermittently
    failing
    + S8201785: Make ModRefBarrierSetAssembler abstract on all
    platforms
    + S8201788: Number of make jobs wrong for bootcycle-images
    target
    + S8201794: [Graal] fix regressions from JDK-8187490
    + S8201799: Build failures after JDK-8195099 (Concurrent
    safe-memory-reclamation mechanism)
    + S8201800: Add support for adjusting heap addresses in a TLAB
    + S8201826: G1: Don't invoke WeakProcessor if mark stack has
    overflowed
    + S8201850: [AOT] vm crash when run test
    compiler/aot/fingerprint/SelfChangedCDS.java
    + S8202000: AIX build broken after JDK-8195099
    + S8202037: Split slow ctw_1 tests
    + S8202052: Disable warnings when building libawt with VS2017
    + S8202060: Add javax/net/ssl/DTLS/CipherSuite.java to
    ProblemList
    + S8202062: Put FileChannel and FileOutpuStream variants of
    AtomicAppend on problem list
    + S8202070: Cleanup code after JDK-8200450, JDK-8200366
    + S8202073: MetaspaceAllocationTest gtest shall lock during
    space creation
    + S8202074: Metaspace: If humongous chunk is added to
    SpaceManager, previous current chunk may not get retired correctly.
    + S8202075: Crash when running
    compiler/codecache/OverflowCodeCacheTest.java
    + S8202079: [s390]: Build failure w/o precompiled headers
    + S8202081: Introduce CollectedHeap::is_oop()
    + S8202091: Rename DualStackPlainSocketImpl to PlainSocketImpl
    [win]
    + S8202134: Non-PCH build for arm32 fails
    + S8202141: Unique symbols for .class
    + S8202151: [BACKOUT] Split globals.hpp to factor out the Flag
    class
    + S8202152: test/hotspot/jtreg/runtime/whitebox/WBStackSize.java
    fails
    + S8202154: Remove unused code in
    java.base/windows/native/libnet
    + S8202155: quarantine test com/sun/jdi/JdbExprTest.sh on all
    platforms
    + S8202157: remove the use of string keys at
    InapplicableMethodException
    + S8202164: Remove some unneeded BoolObjectClosure* is_alive
    parameters
    + S8202169: Reduce ctw_2 duration by parallelizing CtwRunner
    invocations
    + S8202184: Reduce time blocking the ClassSpecializer cache
    creating SpeciesData
    + S8202210: jlink uses little-endian for big-endian
    cross-compilation targets
    + S8202276: Update test/hotspot/jtreg/ProblemList-graal.txt
- Removed patch:
  * bootcycle_jobs.patch
    + Integrated upsteam
* Fri Apr 20 2018 fstrba@suse.com
- Update to upstream tag jdk-11+10 (April 2018 CPU)
  * Security fixes:
    + S8194238: Trying exceptions in MethodHandles (CVE-2018-2826,
    bsc#1090197)
    + S8194233: Improve support for array handles (CVE-2018-2825,
    bsc#1090196)
    + S8192025: Less referential references (CVE-2018-2814,
    bsc#1090032)
    + S8189997: Enhance keystore mechanisms (CVE-2018-2794,
    bsc#1090024)
    + S8189977: Improve permission portability (CVE-2018-2795,
    bsc#1090025)
    + S8189993: Improve document portability (CVE-2018-2799,
    bsc#1090029)
    + S8189989: Improve container portability (CVE-2018-2798,
    bsc#1090028)
    + S8189985: Improve tabular data portability (CVE-2018-2797,
    bsc#1090027)
    + S8189981: Improve queuing portability (CVE-2018-2796,
    bsc#1090026)
    + S8189969: Manifest better manifest entries (CVE-2018-2790,
    bsc#1090023)
  * Security-In-Depth fixes:
    + S8182362: Update CipherOutputStream Usage
    + S8183032: Upgrade to LittleCMS 2.9
    + S8189123: More consistent classloading
    + S8190478: Improved interface method selection
    + S8190877: Better handling of abstract classes
    + S8191696: Better mouse positioning
    + S8192030: Better MTSchema support
    + S8193409: Improve AES supporting classes
    + S8193414: Improvements in MethodType lookups
  * Fixes:
    + S8009632: (fs) FileStore.supportsFileAttributeView does not
    detect user_xattr enabled on ext4
    + S8049695: nsk/jdb/options/connect/connect003 fails with
    "Launched jdb could not attach to debuggee during 300000
    milliseconds"
    + S8057732: sun/jvmstat/monitor/MonitoredVm/
    /MonitorVmStartTerminate.java: Invalid PerfMemory size
    + S8078221: java/rmi/Naming/DefaultRegistryPort.java fails
    intermittently
    + S8151171: Bring g1ConcurrentMark files up to current coding
    conventions
    + S8152821: Merge jdk.internal.misc.JavaSecurityAccess and
    jdk.internal.misc.JavaSecurityProtectionDomainAccess shared
    secrets
    + S8175075: Add 3DES to the default disabled algorithm security
    property
    + S8180415: Rebuild remembered sets during the concurrent cycle
    + S8183238: Obsolete CheckEndorsedAndExtDirs and remove checks
    for lib/endorsed and lib/ext
    + S8184692: add Pattern.asMatchPredicate
    + S8186032: Disable XML Signatures signed with EC keys less
    than 224 bits
    + S8187472: AARCH64: array_equals intrinsic doesn't use
    prefetch for large arrays
    + S8189101: AARCH32 - 'minimal' build fails because CMS bits
    are referred unconditionally
    + S8189765: Improve error reporting for compiling against
    package not visible due to modules
    + S8191101: Show register content in hs-err file on assert
    + S8191358: Restore TSA certificate expiration check
    + S8193067: gc/g1/TestVerifyGCType.java still unstable
    + S8194259: keytool error: java.io.IOException: Invalid secret
    key format
    + S8194260: Point-to-point interface should be excluded from
    java/net/ipv6tests/*
    + S8194734: Handle to jimage file inherited into child
    processes (win)
    + S8194750: Console.readPassword does not save/restore tty
    settings
    + S8194812: Extend class-data sharing to support the module path
    + S8195099: Concurrent safe-memory-reclamation mechanism
    + S8195662: Add T6587786.java to problem list before
    JDK-8195589 is resolved
    + S8195972: Refactor oops in JNI to use the Access API
    + S8196289: Update src/java.desktop/share/legal/lcms.md for
    LCMS 2.9
    + S8196485: FromCardCache default card index can cause crashes
    + S8196516: libfontmanager must be built with LDFLAGS allowing
    unresolved symbols
    + S8196865: G1 log for active workers is wrong
    + S8197441: Signature#initSign/initVerify for an invalid
    private/public key fails with ClassCastException for SunPKCS11
    provider
    + S8197443: ArrayIndexOutOfBoundsException in
    UcryptoException.getError
    + S8197564: HTTP Client implementation
    + S8197569: Refactor eager reclaim for concurrent remembered
    set rebuilding
    + S8197570: Make rules for choosing collection set candidates
    more explicit
    + S8197573: Remove concurrent cleanup and secondary free list
    handling
    + S8197850: Calculate liveness in regions during marking
    + S8197928: Only enqueue deferred cards with references into
    regions that have a tracked remembered set during GC
    + S8197931: Null pointer dereference in Unique_Node_List::push
    of node.hpp:1510
    + S8197932: Better split work in rebuild remembered sets phase
    + S8197972: Always verify non-system classes during CDS dump
    time
    + S8198240: Allow cacerts test to pass when GTECyberTrust root
    expires
    + S8198313: Wrap holder object for ClassLoaderData in a
    WeakHandle
    + S8198335: java/awt/FullScreen/UninitializedDisplayModeChangeTest/
    /UninitializedDisplayModeChangeTest.java fails in headless mode
    + S8198393: Instrumentation.retransformClasses() throws
    NullPointerException when handling a zero-length array
    + S8198655: test/lib/jdk/test/lib/apps/LingeredApp shouldn't
    inherit cout/cerr
    + S8198691: CodeHeap State Analytics
    + S8198760: Move global lock SpaceManager::_expand_lock to
    MutexLocker.cpp
    + S8198908: Add JVM support for preview features
    + S8198915: [Graal] 3rd testcase of compiler/types/
    /TestMeetIncompatibleInterfaceArrays.java takes more than 10
    mins
    + S8198950: AArch64:
    org.openjdk.jcstress.tests.varhandles.DekkerTest fails
    + S8199007: ClassLoaderDataGraph::unload_list_contains() is
    wrong
    + S8199194: Add javac support for preview features
    + S8199326: Remove G1 gc time stamp logic
    + S8199360: Rework the support for the 'ignored' module options
    in CDS
    + S8199406: Performance drop with Java JDK 1.8.0_162-b32
    + S8199417: Modularize interpreter GC barriers
    + S8199619: Building HotSpot on Windows should define NOMINMAX
    + S8199627: Use "Per-Monitor V2" High DPI awareness for Windows
    10 v1703
    + S8199717: Avoid calculating primordial thread stack bounds on
    VM startup
    + S8199735: Mark word updates need to use Access API
    + S8199736: Define WIN32_LEAN_AND_MEAN before including
    windows.h
    + S8199742: Clean up state flags in G1CollectorState
    + S8199780: SetMemory0 and CopyMemory0 in unsafe.cpp need to
    resolve their operands
    + S8199781: Don't use naked == for comparing oops
    + S8199782: Fix compilation warnings detected by Solaris
    Developer Studio 12.6
    + S8199793: [Graal] runtime/CommandLine/
    /PrintTouchedMethods.java crashes with assertion "reference
    count underflow for symbol"
    + S8199813: SIGSEGV in ThreadsList::includes()
    + S8199850: Move parsing of VerifyGCType to G1
    + S8199918: Shorten names of CollectedHeap::Name members
    + S8199925: Break out GC selection logic from GCArguments to
    GCConfig
    + S8199927: Make WhiteBox more GC agnostic
    + S8199946: Move load/store and encode/decode out of oopDesc
    + S8200067: Add support for vpclmulqdq for crc32
    + S8200074: Remove
    G1ConcurrentMark::_concurrent_marking_in_progress
    + S8200078: [Graal] runtime/appcds/GraalWithLimitedMetaspace.java
    crashes in visit_all_interfaces
    + S8200091: [TESTBUG] Update jittester for jdk11
    + S8200105: Remove cyclic dependency between oop.inline.hpp and
    collectedHeap.inline.hpp
    + S8200106: Move NoSafepointVerifier out from gcLocker.hpp
    + S8200111: MallocArrayAllocator::free should not take a length
    parameter
    + S8200113: Make Access load proxys smarter
    + S8200126: [TESTBUG] Open source VM runtime signal tests
    + S8200149: The "com.sun.awt.AWTUtilities" class can be dropped
    + S8200168: Remove DONT_USE_REGISTER_DEFINES on Sparc
    + S8200169: Flatten G1Allocator class hierarchy
    + S8200187: Exclude 3 long-running tests from tier1
    + S8200195: serviceability/jvmti/FieldAccessWatch/
    /FieldAccessWatch.java crashes with
  "assert(thread->thread_state() == _thread_in_native) failed:
    coming from wrong thread state"
    + S8200197: Zero fails to build after 8200105
    + S8200202: Remove unused _boot_modules_array and
    _platform_modules_array from classLoader.*.
    + S8200203: Missing platform definitions for ia64
    + S8200227: [Graal] Test times out with Graal due to low
    compile threshold
    + S8200228: Change default value of HeapSizePerGCThread
    + S8200230: [Graal] Compilations should not be enqueued before
    Graal is initialized
    + S8200232: Build failures after JDK-8200106 (Move
    NoSafepointVerifier out from gcLocker.hpp)
    + S8200233: Simple G1 evacuation path performance enhancements
    + S8200234: Cleanup Remark and Cleanup pause code
    + S8200238: Reduce number of exceptions created when calling
    MemberName$Factory::resolveOrNull
    + S8200245: Zero fails to build on linux-ia64 due to
    ia64-specific cruft
    + S8200246: AIX build fails after adjustments of
    src/hotspot/share/trace/traceEventClasses.xsl
    + S8200251: AArch64::CPUFeature out of sync with
    VM_Version::Feature_Flag
    + S8200255: Remove G1CMTask::_concurrent
    + S8200261: Regression with JVM anonymous class
    + S8200276: Cleanup allocation.hpp includes
    + S8200290: Scratch buffer creation fails with
    "assert(!current_thread_in_native()) failed: must not be in
    native" on SPARC
    + S8200292: Move PushAndMarkVerifyClosure::do_oop_work to
    concurrentMarkSweepGeneration.cpp
    + S8200297: Build failures after JDK-8198691 (CodeHeap State
    Analytics)
    + S8200299: Non-PCH build for aarch64 fails
    + S8200302: ppc, s390 (non-pch) build errors
    + S8200305: Update gc,liveness output with remset state after
    rebuild remset concurrently changes
    + S8200343: Minor JViewport documentation typo
    + S8200360: MeetIncompatibleInterfaceArrays fails with
    "MeetIncompatibleInterfaceArrays0ASM.run() must be compiled at
    tier 0 !"
    + S8200362: G1Mux2Closure should disable implicit oop
    verification
    + S8200366: SIGSEGV in CodeHeapState::print_names()
    + S8200371: In g1, rename ConcurrentMarkThread to
    G1ConcurrentMarkThread
    + S8200374: Add
    ThreadsSMRSupport::verify_hazard_pointer_scanned() to verify
    threads_do().
    + S8200383: Can't build on SPARC Hotspot with code which use
    math functions
    + S8200384: jcmd help output should be sorted
    + S8200385: Eagerly reclaimed humongous objects leave mark in
    prev bitmap
    + S8200391: clean up test/hotspot/jtreg/ProblemList.txt
    (compiler related)
    + S8200423: Non-PCH build for x86_32 fails
    + S8200424: Windows build fails due to implicit jboolean to
    bool conversion
    + S8200429: Adjust object pinning interface on CollectedHeap
    + S8200438: Non-PCH x86_32 build failure: err_msg is not defined
    + S8200461: MeetIncompatibleInterfaceArrays test fails with
  - Xcomp
    + S8200468: Port the native GSS-API bridge to Windows
    + S8200524: AArch64: CPUFeature and Flag enums are not passed
    through JVMCI
    + S8200525: test java/awt/event/SequencedEvent/SequencedEventTest.java
    fails to compile
    + S8200526: Test sun/java2d/marlin/ClipShapeTest.java times out
    + S8200550: Xcode 9.3 produce warning -Wexpansion-to-defined
    + S8200607: Add missing include dependency in bitMap.hpp
    + S8200608: Build failures after JDK-8191101 (Show register
    content in hs-err file on assert)
    + S8200626: Restore history for g1ConcurrentMarkThread.*
    + S8200627: aarch32 - Broken build after JDK-8198949
    + S8200628: aarch32 - Broken build after JDK-8199809
    + S8200630: Globally suppress Visual Studio warning C4351
    + S8200697: Add utility for spin wait with fallback to
    yield/sleep
    + S8200719: Cannot connect to IPv6 host when exists any active
    network interface without IPv6 address
    + S8200735: Move CMS specific code from binaryTreeDictionary
    and freeList to CMS files
    + S8200736: Move CMSGCStats to the cms directory
    + S8200737: Move GC code out of
    Arguments::check_vm_args_consistency into GCArguments
    + S8200759: Move GC entries in vmStructs.cpp to GC specific
    files
    + S8201136: Move GC flags from globals.hpp to GC specific files
    + S8201167: Remove MacroAssembler::cmp_heap_oop on x86
    + S8201168: Move GC command line constraint functions to GC
    specific files
    + S8201171: Cleanup in g1CollectedHeap, change CamelCase to
    snake_case
    + S8201175: Move FilteringClosure::do_oop to genOopClosures
    + S8201185: AARCH64: bfm instruction encoding hits assert on
    zero register
    + S8201209: Separate out CMS specific functions into
    CMSCardTable
    + S8201212: Remove INCLUDE_ALL_GCS from OopStorage files
    + S8201213: Remove INCLUDE_ALL_GCS from
    memset_with_concurrent_readers
    + S8201217: Split specialized_oop_closures.hpp into GC specific
    files
    + S8201218: PPC64: Avoid use of yield instruction on spinlock
    + S8201227: Add ALL_GCS_ONLY
    + S8201240: Improve releasing native resources of
    BufImgSurfaceData.ICMColorData
    + S8201242: Include source file/line number when reporting
    native call stack on supported platforms
    + S8201244: Clean out unnecessary includes of heap headers
    + S8201247: Various cleanups in the attach framework
    + S8201265: Native memory leak in
    ClassLoader::add_to_exploded_build_list
    + S8201316: Move G1-related static members from JavaThread to
    G1BarrierSet
    + S8201318: Introduce GCThreadLocalData to abstract GC-specific
    data belonging to a thread
    + S8201321: NMT: Unnecessary re-recording thread stack and size
    when attaching listener to JavaThread
    + S8201330: Add java/lang/management/ThreadMXBean/
    /ThreadMXBeanStateTest.java to the ProblemList
    + S8201334: Move runtime/NMT/MallocStressTest.java to
    hotspot_tier3_runtime
    + S8201359: Incorrect header guards after JDK-8198949
    (Modularize arraycopy stub routine GC barriers)
    + S8201362: Remove CollectedHeap::barrier_set()
    + S8201365: Remove G1Policy::should_process_references()
    + S8201370: GC specific data is referred from common
    precompiled headers and defNewGeneration.cpp
    + S8201427: Fix Minimal VM builds on Linux x64
    + S8201430: [TESTBUG] Remove script from runtime/6626217
    + S8201442: objArrayOopDesc::atomic_compare_exchange_oop() must
    use obj+offset in HeapAccess call
    + S8201443: NoSuchMethodException JarFile.open when jar file is
    used in classpath
    + S8201450: Provide access to LogHandle tagset
    + S8201474: (so) Socket adaptor connect(InetAddress, timeout)
    succeeds when connection fails
    + S8201475: 8199417 breaks AIX and non-pch on s390 (and
    presumably aarch64)
    + S8201480: ISA/CPU feature detection code crashes on
    linux-sparc
    + S8201483: Make it possible to disable JVM features
    + S8201494: Avoid early initialization of java.nio.Bits
    + S8201495: [Zero] Reduce limits of max heap size for boot JDK
    on s390
    + S8201498: test/langtools/tools/javac/diags/CheckExamples.java
    6 errors occurred
    + S8201507: Generate alias entries in j.t.f.ZoneName from tzdb
    at build time
    + S8201508: Macosx builds fail in GenerateLinkOptData.gmk
    + S8201554: Disable failing tier1 test for JDK-8201498
    + S8201584: Fix configure on SLES 11 after 8201483
    + S8201591: JVM features with "-" in name is not correctly
    handled
    + S8201609: Split test/jdk/:tier2 to enable better parallel
    execution
- Removed patch
  * fix-arm-build.patch
    + Integrated upstream
- Modified patch:
  * memory-limits.patch
    + Rediff with changes in the right files
* Thu Apr 19 2018 guillaume.gardet@opensuse.org
- Fix armv6 build with fix_armv6_build.patch
* Fri Apr 13 2018 fstrba@suse.com
- Update to upstream tag jdk-11+9
  * Fixes
    + S8071367: JMX: Remove SNMP support
    + S8164781: Pattern.asPredicate specification is incomplete
    + S8178867: tools/jlink/multireleasejar/
    /JLinkMultiReleaseJarTest.java failed to clean up files
    + S8180570: Refactor sun/security/mscapi shell tests to plain
    java tests
    + S8188897: java/rmi/registry/reexport/Reexport.java failed
    with Port already in use
    + S8189784: Parsing with Java 9 AKST timezone returns the
    SystemV variant of the timezone
    + S8190333: sun/security/ssl/X509KeyManager/PreferredKey.java
    failed with "Failed to get the preferable key aliases"
    + S8196200: Implement a navigation builder in javadoc
    + S8196724: Change macosx deployment target to 10.9
    + S8196750: [Testbug] tools/launcher tests need to tolerate
    unrelated warnings
    + S8196775: java/net/Socket/asyncClose/Race.java failed
    intermittently on Windows with ConnectException: Connection
    refused
    + S8197418: Move java/util/RandomAccess/ tests into OpenJDK
    + S8197531: Miscellaneous changes imported from jsr166 CVS
    2018-04
    + S8199539: Provide a standard way for the build to filter
    un-needed legal .md files
    + S8199608: Clean up LDFLAGS for libfontmanager
    + S8199744: Incorrect compiler message for ReceiverParameter in
    inner class constructor
    + S8199875: Require first parameter type of a condy bootstrap
    to be Lookup
    + S8200125: Fix some classloader/module typos
    + S8200127: Replace collection.stream().forEach() with
    collection.forEach()
    + S8200128: Fix some "annoations" typos
    + S8200131: Improve lazy init of InetAddress.canonicalHostName
    and NativeObject.pageSize
    + S8200134: Improve ModuleHashesBuilder
    + S8200152: KerberosString should use UTF-8 by default
    + S8200258: Improve CopyOnWriteArrayList subList code
    + S8200298: Unify all unix versions of libjsig/jsig.c
    + S8200358: Remove mapfiles for JDK executables
    + S8200359: (tz) Upgrade time-zone data to tzdata2018d
    + S8200458: (se) Readiness information previously recorded in
    the ready set not preserved
    + S8200520: forkjoin tasks interrupted after shutdown
    + S8200583: (se) Selector clean-up, part 4
    + S8200664: fix broken links in java.base docs
    + S8200706: Better cleanup for open/test/jdk/java/lang/
    /ProcessBuilder/DestroyTest.java
    + S8200727: linux-aarch64 profile should use bundled freetype
    + S8200728: Docs (Comparison of Stack and Deque methods) for
    Deque is not correct
    + S8200788: Optimal initial capacity of
    java.lang.VarHandle.AccessMode.methodNameToAccessMode
    + S8200792: PKCS12Attribute#hashCode is always constant -1
    + S8200888: typo in name of exception in @throws
    + S8201178: Remove sun.nio.cs.FastCharsetProvider
    + S8201179: Regression due loading
    java.nio.charset.StandardCharsets during bootstrap
    + S8201194: Handle local variable declarations in lambda
    deduplication
    + S8201221: JDK-8199608 introduced a build race on macosx
    + S8201222: JDK-8199539 broke the OpenJDK build
    + S8201236: Straighten out dtrace build logic
    + S8201246: Export native function to set platform encoding
    + S8201251: The tests for JDK-8187247 should be under
    test/langtools
    + S8201263: Trailing backslash in VS120COMNTOOLS leads to ugly
    error message when running tests
    + S8201267: Disable warnings for VS2017 to enable building
    + S8201320: Allow PrintFailureReports to be turned off
    + S8201327: Make Sensor deeply immutably thread safe
    + S8201328: SynthParser should use Boolean.parseBoolean
    + S8201348: ProblemList update for bugid associated with
    SSLSocketParametersTest.sh
    + S8201357: ALSA_CFLAGS is needed; was dropped in JDK-8071469
    + S8201396: fix broken links generated by javadoc doclet
    + S8201439: Enable linux-arm-vfp-hflt profile to be configured
    with jib again
    + S8201440: javac should create unique DynamicMethodSymbols at
    LambdaToMethod
- Modified patches:
  * java11-improved-fonts.patch
    + Rediff to changed context
  * fix-arm-build.patch
    + Use upstream fixes
* Wed Apr 11 2018 fstrba@suse.com
- Modified patch:
  * fix-arm-build.patch
    + fix more duplicate commas in headers
* Fri Apr  6 2018 fstrba@suse.com
- Update to upstream tag jdk-11+8
  * Fixes
    + S4954348: JPGWriter.getNumThumbnailsSupported does not return
  - 1 when passing null values
    + S8074286: Add getSelectedIndices() to ListSelectionModel
    + S8178370: [TEST_BUG]
    java/security/Signature/SignatureLength.java fails
    + S8191957: JFileChooser shows empty name for external drives
    shown under Desktop
    + S8193032: Remove terminally deprecated SecurityManager APIs
    + S8195649: reorganize tests for java.util.Optional
    + S8198314: javac hidden options violate standard syntax for
    options
    + S8198801: JShell: user exception chained cause not retained
    + S8198885: upgrade Marlin (java2d) to 0.9.1
    + S8198990: Move SwingSet2 from closed to OpenJDK
    + S8199176: Accessibility issues in java.base docs
    + S8199800: Optimize Boolean.parseBoolean(String)
    + S8199947: Rename HTML element id in ClassLoader javadoc to
    avoid name conflict with private elements
    + S8200200: test java/awt/image/ColorModel/Non_sRGBCMTest.java
    fails with open profiles
    + S8200257: (se) More Selector cleanup
    + S8200267: a.out created at top dir by Solaris build
    + S8200364: Remove unnecessary boxing via primitive wrapper
    valueOf(String) methods
    + S8200375: Change to GCC 7.3.0 for building Linux at Oracle
    + S8200469: Update link to license in Docs.gmk
    + S8200538: cl : Command line warning D9014 : invalid value
    '2220' for '/wd'
    + S8200586: Update JDK11 release date to 2018-09-25
    + S8200658: Fix incremental builds of hotspot on solaris
    + S8200696: Optimal initial capacity of
    java.lang.Class.enumConstantDirectory
    + S8200703: Problem list jdk/jshell/ExceptionsTest.java fails
    on windows
* Thu Apr  5 2018 fstrba@suse.com
- Added patch:
  * fix-arm-build.patch
    + fix a duplicate comma in a header
* Tue Apr  3 2018 fstrba@suse.com
- Update to upstream tag jdk-11+7
  * Fixes:
    + S4912693: Behavior of null arguments not specified in Java
    Sound
    + S6686236: GIF native IIOMetadata assumes
    characterCellWidth/Height as 2bytes
    + S7031957: DIB header of type BITMAPV2INFOHEADER &
    BITMAPV3INFOHEADER is not supported in BMPImageReader
    + S7108280: JList.getSelectedValuesList fails if
    JList.setSelectionInterval larger than list
    + S7158623: Should an unfocusable maximized Frame be resizable
    + S8071282: remove misc dead code
    + S8071469: Cleanup include and exclude of sound native
    libraries
    + S8140359: get_locked_message_ext() should return Flag::MsgType
    + S8144300: http.nonProxyHosts value having wildcard * both at
    end and start are not honored
    + S8146201: [AOT] Class static initializers that are not pure
    should not be executed during static compilation
    + S8152974: AWT hang occurrs when sequenced events arrive out
    of sequence
    + S8153333: [REDO] STW phases at Concurrent GC should count in
    PerfCounte
    + S8159850: Remove unneeded parsing of optional-size when
    parsing array types
    + S8166642: serviceability/dcmd/framework/* timeout
    + S8170541: serviceability/jdwp/AllModulesCommandTest.java
    fails intermittently on Windows and Solaris
    + S8173070: Remove ValueObj class for allocation subclassing
    for runtime code
    + S8173100: AArch64: -XX:-UseOnStackReplacement does not work
    together with -XX:+TieredCompilation
    + S8175312: SA: clhsdb: Provide an improved heap summary for
    'universe' for G1GC
    + S8180410: ByteArrayOutputStream should not throw IOExceptions
    + S8180451: ByteArrayInputStream should override readAllBytes,
    readNBytes, and transferTo
    + S8191102: Incorrect include file use in classLoader.hpp
    + S8191418: List.of().indexOf(null) doesn't throw
    NullPointerException
    + S8191585: VM anonymous classes created during CDS dump time
    cause crash
    + S8191924: Adjust DelegatingClassLoader's metadata space
    sizing algorithm
    + S8191954: AArch64: disable UseCISCSpill in C2
    + S8193128: Reduce number of implementation classes returned by
    List/Set/Map.of()
    + S8193130: Bad graph when unrolled loop bounds conflicts with
    range checks
    + S8193266: AArch64: TestOptionsWithRanges.java SIGSEGV
    + S8193369: post_field_access does not work for some functions,
    possibly related to fast_getfield
    + S8193429: "assert(false) failed: GetModuleFileName failed
    (126)" in symbolengine.cpp
    + S8193434: [GRAAL] Graal classes are not loaded with
  - Xshare:dump
    + S8194054: [TESTBUG] Test runtime/CommandLine/
    /OptionsValidation/TestOptionsWithRanges.java failed with
  - 1073740940 (FFFFFFFFC0000374)
    + S8194490: [JVMCI] Move `iterateFrames` to C++
    + S8194746: (fs) Add equivalents of Paths.get to Path interface
    + S8194759: Support caching class mirror objects.
    + S8194978: Javac produces dead code for try-with-resource
    + S8195095: Images are not scaled correctly in JEditorPane
    + S8195109: ServiceUtil::visible_oop is not needed anymore
    + S8195148: Collapse G1SATBCardTableModRefBS and
    G1SATBCardTableLoggingModRefBS into a single G1BarrierSet
    + S8196028: JMX: Not enough JDP packets received before timeout
    + S8196121: runtime/appcds/ClassLoaderTest.java fails silently
    + S8196294: LoopStripMiningIterShortLoop is set to zero by
    default
    + S8196337: Add commit methods that take all event properties
    as argument
    + S8196399: Formatting a decimal using locale-specific grouping
    separators causes ArithmeticException (division by zero).
    + S8196519: Incomplete classpath causes infinite recursion in
    Resolve.isAccessible
    + S8196590: Enable docker container related tests for linux
    AARCH64
    + S8196626: [Graal] runtime/appcds/UseAppCDS.java crashes with
    "VM thread using lock Heap_lock (not allowed to block on)"
    + S8196668: revisit test SunPackageAccess and
    GrantedSunPackageAccess
    + S8196876: OopStorage::assert_at_safepoint clashes with
    assert_at_safepoint macros in g1CollectedHeap.hpp
    + S8197235: src/hotspot/share/jvmci/jvmciCompilerToVM.cpp takes
    4 minutes to compile on windows
    + S8197405: Improve messages of AbstractMethodErrors and
    IncompatibleClassChangeErrors.
    + S8197429: Increased stack guard causes segfaults on x86-32
    + S8197554: Create test for SwingSet TableDemo
    + S8197595: Serialization javadoc should link to security best
    practices
    + S8197842: Remove unused macros VM_STRUCTS_EXT and VM_TYPES_EXT
    + S8197843: Remove unused method
    G1EvacuationRootClosures::create_root_closures_ext
    + S8197844: JVMTI GetLoadedClasses should use the Access API
    + S8197845: Remove unnecessary method
    G1CollectedHeap::create_g1_policy
    + S8197847: Remove unused file g1ParScanThreadState_ext.cpp
    + S8197852: Move G1DefaultPolicy into G1Policy
    + S8197944: Condy tests fails on Windows
    + S8198243: Add build time check for global operator new/delete
    in object files
    + S8198358: Align organization of TwoStacksPlainSocketImp with
    DualStackPlainSocketImpl [win]
    + S8198423: Improve metaspace chunk allocation
    + S8198424: Remove G1AllocationContext
    + S8198430: Remove G1Allocator extension point
    + S8198431: Remove G1FullCollector extension point
    + S8198432: Remove Thread extension point
    + S8198433: Remove WhiteBox extension point
    + S8198445: Access API for primitive/native arraycopy
    + S8198447: Remove ClassLoaderExt::check().
    + S8198510: Enable UseDynamicNumberOfGCThreads by default
    + S8198546: [Redo] JDK-8196883 G1RemSet::refine_card_concurrently
    doesn't need to check for cards in collection set
    + S8198552: Multiple javac plugins do not work at the same time.
    + S8198571: [JVMCI] must not install wide vector code unless
    runtime supports it
    + S8198591: compiler/aot/fingerprint tests should be moved to
    open
    + S8198608: Improvements to command-line flags printing
    + S8198649: Switch AWT/Swing's default GTK version to 3
    + S8198652: Stop linking with -base:0x8000000 on Windows
    + S8198753: (dc) DatagramChannel throws unspecified exceptions
    + S8198789: [TESTBUG] CTW of java.base and java.desktop takes
    long time
    + S8198794: Hotspot crash on Cassandra 3.11.1 startup with
    libnuma 2.0.3
    + S8198796: Create test case for CDS + condy
    + S8198826: -XX:+VerifyStack fails with fatal error:
    ExceptionMark constructor expects no pending exceptions
    + S8198833: TestMemoryAwareness Docker container fails with too
    small maximum heap
    + S8198845: Missing resource mark results disassembling
    generated code failure in hs error report
    + S8198894: [PPC64] More generic vector CRC implementation
    + S8198895: Compilation errors in java.desktop with VS 2017
    + S8198896: Remove dead code: cardTableModRefBSForCTRS.hpp
    + S8198897: Compilation errors in jdk.accessibility with VS 2017
    + S8198906: JDK-8196882 breaks VS2013 Win32 builds
    + S8198924: [Graal] java/lang/StackWalker/LocalsAndOperands.java
    timeouts with Graal
    + S8198926: Move ClassLoaderData::_dependencies to
    ClassLoaderData::_handles
    + S8198948: Remove unused parameter evacuation_info from
    G1CollectedHeap::evacuate_collection_set
    + S8198949: Modularize arraycopy stub routine GC barriers
    + S8198950: AArch64:
    org.openjdk.jcstress.tests.varhandles.DekkerTest fails
    + S8198957: Remove unused function
    ArgumentsExt::set_gc_specific_flags
    + S8198969: Update Graal
    + S8198987: [Graal] compiler/intrinsics/sha/sanity tests fail
    on macos with Graal as JIT
    + S8198997: Cache normalized/resolved user.dir property
    + S8199010: attachListener.hpp: Fix potential null termination
    issue found by coverity scans
    + S8199012: SEGV in jni_DetachCurrentThread during VM shutdown
    + S8199024: Remove unneccessary protected and virtual modifiers
    from G1CollectedHeap
    + S8199027: Make protected members private in G1Policy
    + S8199050: reenable concurrent execution of compiler tests
    + S8199066: [JVMCI] EagerJVMCI option should also initialize
    the JVMCI compiler
    + S8199133: [BACKOUT] NMT: Enhance thread stack tracking
    + S8199137: StringInternSync test crashes in exit verification
    + S8199212: [TESTBUG] don't run compiler/aot tests with -Xcomp
    + S8199219: Build failures after JDK-8195148 (Collapse
    G1SATBCardTableModRefBS and G1SATBCardTableLoggingModRefBS
    into a single G1BarrierSet)
    + S8199220: Zero build broken after 8195103, 8191102 and 8189871
    + S8199243: aarch32: ARM 32 build broken after 8165929
    + S8199263: Split interfaceSupport.hpp to not require including
    .inline.hpp files
    + S8199264: Remove universe.inline.hpp to simplify include
    dependencies
    + S8199272: Broken assertion in ClassLoaderData::remove_handle
    + S8199275: Fix inclusions of allocation.inline.hpp
    + S8199278: Javadoc search results does not link to anchors on
    a page
    + S8199282: Remove ValueObj class for allocation subclassing
    for gc code
    + S8199283: Remove ValueObj class for allocation subclassing
    for compiler code
    + S8199319: Remove handles.inline.hpp include from
    reflectionUtils.hpp
    + S8199323: hsdis could not be loaded which are located on long
    path
    + S8199328: Fix unsafe field accesses in heap dumper
    + S8199342: The constant pool forgets it has a Dynamic entry if
    there are overpass methods
    + S8199356: Fix hotspot to allow stdlib to use libc++ and to
    allow changing the deployment target to 10.9
    + S8199421: Add support for vector popcount
    + S8199422: Hotspot build is broken after push of 8197235
    + S8199425: JTReg failure:
    runtime/stringtable/StringTableVerifyTest.java
    + S8199430: Rename MetaspaceAux to something more meaningful
    + S8199431: Split up class Metaspace into a static and a
    non-static part
    + S8199432: metaspace: fix wrong comment and condition in
    SpaceManager::verify()
    + S8199465: {@docRoot} references need to be updated to reflect
    new module/package structure
    + S8199467: Compilation Errors in libinstrument Reentrancy.c
    with VS2017
    + S8199472: Fix non-PCH build after JDK-8199319
    + S8199489: [TESTBUG] don't run CTW tests with -Xcomp
    + S8199511: Do not generate g1_{pre|post}_barrier_slow_id
    without CardTable-enabled barrier set
    + S8199516: Remove dead code overlooked during Full GC work
    + S8199518: test/hotspot/jtreg/runtime/SelectionResolution
    tests take a lot longer to run with fastdebug after JDK-8198423
    + S8199532: [TESTBUG] AbstractMethodErrorTest.java test failed
    with -Xcomp
    + S8199533: ProblemList tests failing after JDK-8153333
    + S8199557: Assert in fromTonga/vm/runtime/defmeth/scenarios/
    /Stress_noredefine/TestDescription.java
    + S8199559: objArrayKlass::oop_iterate() and friends must use
    base_raw() instead of base()
    + S8199561: Fix two typos in the JVMTI documentation
    + S8199603: Build failures after JDK-8199421 "Add support for
    vector popcount"
    + S8199604: Rename CardTableModRefBS to CardTableBarrierSet
    + S8199620: Support for JNI object pinning
    + S8199624: [Graal] Blocking jvmci compilations time out
    + S8199656: Make slow metaspace verifications switchable in
    debug builds
    + S8199667: Unify metaspace list index handling and
    reinstantiate ChunkManager listindex gtest
    + S8199672: ClassCastException is thrown by java.util.Formatter
    when an NumberFormatProvider SPI is used.
    + S8199674: Improve G1 Full GC array marking
    + S8199685: Access arraycopy build failure with GCC 7.3.1
    + S8199696: Remove Runtime1::arraycopy
    + S8199698: Change 8199275 breaks template instantiation for
    xlC (and potentially other compliers)
    + S8199705: Docs.gmk needs to be updated to remove the -html5
    option
    + S8199716: Unused AdjustKlassClosure in psParallelCompact.hpp
    + S8199728: Remove oopDesc::is_scavengable
    + S8199739: Use HeapAccess when loading oops from static fields
    in javaClasses.cpp
    + S8199741: NMT: Tag safepoint polling pages
    + S8199752: NMT: Memory allocated by Unsafe.allocateMemory
    should be tagged as mtOther
    + S8199756: Simplify language, country, script, and variant
    property initialization
    + S8199762: JShell API: Failed to detect override when snippet
    to be overridden has been changed before
    + S8199773: (bf) XXXBuffer:compareTo method is not working as
    expected
    + S8199777: Deprecate -XX:+AggressiveOpts
    + S8199784: PhaseIdealLoop::place_near_use() might return wrong
    control with loop strip mining
    + S8199789: Emit a warning message when t2k is selected via
    system property
    + S8199791: (se) More Selector cleanup
    + S8199809: Don't include frame.inline.hpp and other.inline.hpp
    from .hpp files
    + S8199843: Optimize Integer/Long.highestOneBit()
    + S8199870: colorimaging.md needs to remove mention of KCMS
    + S8199880: runtime/appcds/condy/CondyHelloTest.java missing at
    requires vm.cds
    + S8199886: gc/cslocker/TestCSLocker.java crashes
    + S8199896: [Graal] build Graal on all x86 platforms
    + S8199902: {@docRoot} references need to be updated to reflect
    new module/package structure
    + S8199910: Compiler crashes with -g option and variables of
    intersection type inferred by `var`
    + S8199924: Solaris: Correctly enqueue null arguments of attach
    operations
    + S8200071: Fix test/hotspot/jtreg/ProblemList-graal.txt
    + S8200072: Remove un-needed qualified export from java.base to
    java.desktop
    + S8200116: ConstructInflaterOutput, ConstructDeflaterInput
    still spamming test logs
    + S8200118: [TESTBUG] String concat tests should test
    toString() application order
    + S8200122: Remove unused field Thread.threadQ
    + S8200123: Replace Thread.init with telescoping constructor
    + S8200124: Various cleanups in jar/zip
    + S8200129: Remove D3D Performance Counter.
    + S8200135: test/hotspot/jtreg/compiler/jvmci/compilerToVM/
    /GetExceptionTableTest.java is failing after JDK-8194978
    + S8200136: Problem list test/hotspot/jtreg/compiler/jvmci/
    /compilerToVM/GetExceptionTableTest.java
    + S8200174: compare.sh improvements
    + S8200178: Remove mapfiles for JDK native libraries
    + S8200179: (se) More Selector cleanup
    + S8200180: fix a typo in run-test framework documentation
    + S8200181: Remove superflous non-IPv4 code from
    Java_java_net_TwoStacksPlainSocketImpl_socketListen
    + S8200198: javah man pages were not removed by JDK-8191054
    + S8200199: javac suggests to use var even when var is used
    + S8200213: Configure broken on MIPS
    + S8200215: 17th loop of "let foo = ''"; throws ReferenceError
    + S8200229: Simplify building of libjsig
    + S8200241: [TESTBUG] java/lang/String/concat/ tests should not
    force source/target = 9 anymore
    + S8200256: java/nio/channels/AsynchronousChannelGroup/Basic.java
    fails intermittently
    + S8200289: Reduce number of exceptions created when calling
    Lookup::canBeCached
    + S8200301: deduplicate lambda methods
    + S8200304: TwoStacksPlainDatagramSocketImpl and socket cleaner
    + S8200310: Avoid charset lookup machinery in
    java.nio.charset.StandardCharsets
    + S8200355: local variable inference regression test generates
    classfile in test folder
    + S8200357: Inline SoundLibraries.gmk into Lib-java.desktop.gmk
    + S8200409: jdk11 nightly solaris sparc build failure
    + S8200449: ReadAllReadNTransferTo fails occasionally
- Modified patch:
  * system-pcsclite.patch
    + Rediff to changed context
* Fri Mar 23 2018 fstrba@suse.com
- Update to upstream tag jdk-11+6
  * Fixes:
    + S8186228: sun/security/krb5/auto/KdcPolicy.java fails with
    "java.lang.Exception: Does not match. Output is
    c30000c30000c30000"
    + S8193033: remove terminally deprecated
    sun.misc.Unsafe.defineClass
    + S8196298: Add null Reader and Writer
    + S8199437: Improve diagnostic system assertion message in
    com.sun.net.httpserver impl
    + S8199682: Clean up building the saproc library
    + S8199749: Debug symbols are not copied to exploded image on
    Mac
    + S8199768: jdk/test/lib/compiler/CompilerUtils.java needs to
    provide more control over compilation
    + S8199792: Wrong license header in XMLLimitAnalyzer.java
    + S8199858: solaris-x86_64 : unpack200 fails linking with SS12u4
    + S8199862: Examine ProxyBuilder::referencedTypes startup cost
    + S8199865: Avoid initializing ShortCache in ProxyGenerator
    + S8199869: Missing copyright headers in nashorn source code
    + S8199884: JDK-8199749 broke build with make 3.81
* Tue Mar 20 2018 fstrba@suse.com
- Update to upstream tag jdk-11+5
  * Fixes:
    + S8160767: [TEST_BUG]
    java/awt/Frame/MaximizedToIconified/MaximizedToIconified.java
    + S8182684: Further clarify InputStream#available()
    + S8183554: Add constructors with Charset parameter for
    FileReader and FileWriter
    + S8187635: On Windows Swing changes keyboard layout on a
    window activation
    + S8188240: Reflection Proxy should skip static methods
    + S8189230: JDK method:
    java.lang.Integer.numberOfLeadingZeros(int) can be optimized
    + S8190347: [TESTBUG] Test javax/swing/JWindow/
    /ShapedAndTranslucentWindows/TranslucentJComboBox.java fails
    + S8190767: if JFrame is maximized on OS X, all new JFrames
    will be maximized by default
    + S8193017: Import freetype sources into OpenJDK source tree
    + S8193584: (testbug) TestSocketFactory fails intermittently
    with ConcurrentModificationException
    + S8194767: Regression automated Test
    'javax/swing/JEditorPane/6917744/bug6917744.java' fails
    + S8194943: Regression automated test 'open/test/jdk/javax/
    /swing/JInternalFrame/8020708/bug8020708.java' fails
    + S8195738: scroll poistion in ScrollPane is reset after
    calling validate()
    + S8196435: Regression automated Test 'java/awt/Mouse/
    /GetMousePositionTest/GetMousePositionWithOverlay.java' fails
    + S8196748: tools/jar tests need to tolerate unrelated warnings
    + S8197785: javax.accessibility.AccessibleBundle will reload
    the ResourceBundle for every call to toDisplayString
    + S8198406: Test TestAATMorxFont is unstable
    + S8198605: Touch keyboard is shown for a non-focusable text
    component
    + S8198606: Touch keyboard does not hide, when a text component
    looses focus
    + S8198613: Test cases result in failure or timeout when run
    with OpenGL backend
    + S8198777: JList.getPreferredScrollableViewportSize(): fix
    mistake in doc for height calc
    + S8198889: Clarify the throwing of exceptions from
    ConstantBootstraps.invoke
    + S8198922: Provide instrumentation for
    sanity/client/SwingSet/src/ButtonDemoScreenshotTest.java
    + S8198989: Provide more diagnostic IAE messages
    + S8199009: test/jdk/java/util/Locale/SoftKeys.java fails with
    OutOfMemoryError
    + S8199022: New failures should be added to ProblemList
    + S8199215: Re-examine getFreePort method in test
    infrastructure library
    + S8199258: BigInteger.bitLength() should explicitly specify
    behavior when the value is zero
    + S8199329: Remove code that attempts to read bytes after
    connection reset reported
    + S8199420: Update javadoc tags in java.lang.System and related
    + S8199423: Create builds-infra Mach5 job
    + S8199428: install-file macro fails on filenames with space on
    Solaris
    + S8199443: Nashorn multithread bottleneck with "use strict"
    + S8199451: Create linux-aarch64 cross-compilation devkit, and
    fix cross-compilation
    + S8199453: Enable link-time generation of constructor forms
    + S8199462: Use Reference.reachabilityFence in direct
    ByteBuffer methods
    + S8199464: Remove remaining vestiges of
    Java_sun_reflect_Reflection_getCallerClass
    + S8199469: Disable generate-jli-classes when building
    interim-image
    + S8199470: Remove unused property file.encoding.pkg
    + S8199471: Enable generation of callSiteForms at link time
    + S8199473: Support Visual Studio BuildTools with VS2017
    + S8199483: Clean up some non-standard LDFLAGS usage
    + S8199606: Set -lc as global LIBS on solstudio
    + S8199611: (se) Minor selector implementation clean-up
    + S8199616: Fix @module declarations in tier1 tests
    + S8199636: Unify naming for jaas_unix and jaas_nt
    + S8199639: Introduce SetupJdkLibrary and SetupJdkExecutable
    + S8199640: Split up BUILD_LIBKRB5 into the two, unrelated
    compilations it consists of
    + S8199647: java/util/Locale/SoftKeys.java fails with
    OutOfMemoryError again
    + S8199668: make/lib cleanup
    + S8199681: Remove boilerplate code from creating native jtreg
    tests
    + S8199745: JDK-8199668 introduced a build race on macosx
- Modified patches:
  * system-pcsclite.patch
  * java10-improved-fonts.patch -> java11-improved-fonts.patch
    + Rediff to changed context
* Tue Mar 13 2018 fstrba@suse.com
- Update to upstream tag jdk-11+4
  * Fixes:
    + S4993841: (str) java.lang.Character should have a
    toString(int) method
    + S5076761: JList.setSelectedValue(null, ...) doesn't do
    anything
    + S6372077: JarFile.getManifest() should handle manifest
    attribute name 70 bytes
    + S8041626: Shutdown tracing event
    + S8129569: [TEST_BUG] Test java/awt/Frame/
    /MaximizedToUnmaximized/MaximizedToUnmaximized.java fails
    + S8137326: Methods for comparing CharSequence, StringBuilder,
    and StringBuffer
    + S8148871: Possible wrong expression stack depth at deopt point
    + S8153945: Track if log configuration has changed during
    runtime
    + S8168722: Unified Logging configuration output needs
    simplifying
    + S8169358: httpserver does not close connections when
    RejectedExecutionException occurs
    + S8170976: [TESTBUG] LogTestFixture does not restore previous
    logging state
    + S8171000: Robot.createScreenCapture() crashes in wayland mode
    + S8182765: HTML5 must be the default javadoc codegen mode in
    the near future
    + S8186513: [TESTBUG] javax/swing/JInternalFrame/8160248/
    /JInternalFrameDraggingTest.java
    + S8187066: -Xlog:help "=debug" example is not quite accurate
    + S8187653: Lock in CoderResult.Cache becomes performance
    bottleneck
    + S8187950: javax.lang.model APIs throws CompletionFailure or a
    subtype of CompletionFailure.
    + S8190346: improve unified JVM logging help message and
    warnings
    + S8190679: java/util/Arrays/TimSortStackSize2.java fails with
    "Initial heap size set to a larger value than the maximum heap
    size"
    + S8191139: Remove deprecated javax.security.auth.Policy API
    + S8191369: NMT: Enhance thread stack tracking
    + S8191421: Deprecate PrintSafepointStatistics,
    PrintSafepointStatisticsTimeout and
    PrintSafepointStatisticsCount options
    + S8193262: JNI array not released in libsunmscapi
    convertToLittleEndian
    + S8193660: Check SOURCE line in "release" file for closedjdk
    + S8194085: Obsolete the deprecated SafepointSynchronize flags
    and remove related code
    + S8194296: Check copyright of files in make/langtools/tools
    + S8194870: Some regression tests throw NPE exception on a
    specific Solaris 11.2 sun4v sparc machine
    + S8195065: runtime/appcds/ProhibitedPackage.java intermittent
    failure
    + S8195131: Dead code removal for changes present in JDK-8176795
    + S8195142: Refactor out card table from CardTableModRefBS to
    flatten the BarrierSet hierarchy
    + S8195632: [Graal] Introduce EagerJVMCI flag to force eager
    JVMCI initialization
    + S8196064: AArch64: Merging ld/st into ldp/stp in
    macro-assembler
    + S8196133: JShell crashes when attempting to use bad source
    file in class path
    + S8196196: Headful tests should not be run in headless mode
    + S8196322: [macosx] When the screen menu bar is used, clearing
    the default menu bar should permit AWT shutdown
    + S8196338: [TEST_BUG] sanity/client/SwingSet/src/
    /TextFieldDemoTest.java Failed with timeout
    + S8196868: AARCH64: ld/st instructions hit guarantee assert
    while using sp
    + S8196882: VS2017 Hotspot Defined vsnprintf Function Causes
    C2084 Already Defined Compilation Error
    + S8197408: Bad pointer comparison and small cleanup in
    os_linux.cpp
    + S8197453: Add support of extra problem list
    + S8197482: Make Jemmy ComponentChooser lambda friendly
    + S8197499: RepaintManager does not increase double buffer
    after attaching a device with higher resolution
    + S8197533: Move javax.transaction.xa  to its own module
    + S8197538: Remove mention of hotjava paths in MimeTable.java
    + S8197546: Fix for 8171000 breaks Solaris + Linux builds
    + S8197549: Implement a new method similar to waitState() on
    Operator which run the check on event queue
    + S8197594: String#repeat
    + S8197808: Test java/awt/Dialog/MakeWindowAlwaysOnTop/
    /MakeWindowAlwaysOnTop.java fails on Windows
    + S8197841: Remove unused function Universe::create_heap_ext
    + S8197864: VS2017 (C4334) Result of 32-bit Shift Implicitly
    Converted to 64 bits
    + S8197926: java/awt/dnd/ImageTransferTest/ImageTransferTest.java
    doesnt close the windows in HiDPI setting
    + S8198004: javax/swing/JFileChooser/6868611/bug6868611.java
    throws error
    + S8198005: javax/swing/JFileChooser/7199708/bug7199708.java
    throws error
    + S8198252: Null pointer dereference in fold_compares_helper
    + S8198253: ThreadInfo.from(CompositeData) incorrectly accepts
    CompositeData with missing JDK 6 attributes
    + S8198293: AARCH64 - Add CPU detection code for Cavium Thunder
    X2
    + S8198302: VS2017 (C4477) java.base/windows/native/libnet/
    /NetworkInterface_winXP.c incorrect printf format strings
    + S8198304: VS2017 (C4838, C4312) Various conversion issues
    with gtest tests
    + S8198312: VS2017: Upgrade HOTSPOT_BUILD_COMPILER in
    vm_version.cpp
    + S8198333: ProblemList should be updated for headless mode
    + S8198474: Move JNIHandles::resolve into jniHandles.inline.hpp
    + S8198554: Add fuzzy matching for log levels and tags when
    parsing -Xlog
    + S8198628: further simplifications to lambda classification at
    JavacParser
    + S8198640: VS2017 (LNK4281) Link Warning Against Missed ASLR
    Optimization
    + S8198693: Update ProblemsList for mac
    + S8198697: Simplify initialization of platform encoding
    + S8198703: Missing #include "gc/shared/cardTableModRefBS.hpp"
    in graphKit.hpp
    + S8198724: Refactor FLAGS handling in configure
    + S8198750: [s390+x86_32+aarch64] Fix build after jdk-8195142
    + S8198810: URLClassLoader does not specify behavior when URL
    array contains null
    + S8198821: fix test methods access for test
    java/text/Normalizer/NormalizerAPITest.java
    + S8198825: Resolve missing review feedback for JDK-8170976
    + S8198833: TestMemoryAwareness Docker container fails with too
    small maximum heap
    + S8198834: (ch) Enable java/nio/channels/spi/SelectorProvider/
    /inheritedChannel/InheritedChannelTest.java on linux-x64
    + S8198841: Thread.interrupt should set interrupt status while
    holding blockerLock
    + S8198844: Clean up GensrcX11Wrappers
    + S8198859: Use elfedit to silence linker warnings on solaris
    + S8198862: Stop doing funky compilation stuff for dtrace
    + S8198887: JDK-8168722 broke the build on macosx
    + S8198888: Reduce string allocation churn in
    InvokerBytecodeGenerator
    + S8198898: Compilation errors in jdk.crypto.mscapi with VS 2017
    + S8198899: Compilation errors in java.prefs with VS 2017
    + S8198928: (so) SocketChannel connect may deadlock if closed
    at around same time that connect fails
    + S8198931: remove java.xml.bind module dependency for
    com/sun/jndi tests
    + S8198933: Update JDI tests to pass valid URL[]
    + S8198955: String#repeat loop optimization
    + S8198966: To make CoderResult.Cache.cache final and allocate
    it eagerly
    + S8198970: jnu_util.c compilation error on Solaris
    + S8199015: (se) SocketChannelImpl.translateXXXOps access
    channel state without synchronization
    + S8199018: Test crypto provider not registering
    + S8199052: Configure broken on aarch64
    + S8199103: Can't use COMPARE_BUILD with PATCH from custom root
    + S8199118: Filtering of filename for microsoft CL broken on
    newer Cygwin
    + S8199120: (so) SocketChannelImpl read/write don't need
    stateLock when channel is configured non-blocking
    + S8199125: --disable-warnings-as-errors does not work for
    native jtreg test code
    + S8199152: Configure broken on arm32
    + S8199154: Accessibility issues in jdk.security.auth
    + S8199197: Set _NT_SYMBOL_PATH when running tests on windows
    + S8199198: Remove unused functions in jdk.crypto.mscapi native
    code
    + S8199224: Refactor add_native_source in SetupNativeCompilation
    + S8199236: Nashorn uses deprecated HTML tags in Javadoc
    + S8199266: Update boot and build jdk requirements in configure
    + S8199327: nuke var type name after a lambda has been accepted
    + S8199331: Don't limit debug information for fastdebug JDK
    native libraries
    + S8199338: Use -g0 on solstudio also for compiling C programs
    + S8199339: JDK-8198859 broke solaris x64
    + S8199347: Always use -Z7 for debug symbols when compiling on
    Windows
    + S8199352: The Jib artifact resolver in test lib needs to
    print better error messages
    + S8199403: Require binutils 2.18 or newer
    + S8199405: Bump lowest supported gcc to 4.8
    + S8199416: Remove debug output left over since JDK-8198844
- Removed patches:
  * sorted-diff.patch
    + context changed completely
  * jdk10-gcc6.patch
    + not needed
  * boot_jdk_version.patch
    + correct boot versions handled upsteam
- Changed patch:
  * java10-improved-fonts.patch
    + rediffed to changed context
* Fri Mar  2 2018 fstrba@suse.com
- Update to upstream tag jdk-11+3
  * Fixes:
    + S4916621: Update those still using JDIScaffold to use
    TestScaffold instead.
    + S7127700: G1: Replace G1PLAB with PLAB
    + S8038043: Xerces Update: XInclude update
    + S8060094: java/util/Formatter/Basic.java failed in tr locale
    + S8068593: Remove or repurpose unused PerfCounters from
    objectMonitor
    + S8165929: Constify arguments of Copy methods
    + S8166232: jshell tool: cannot access previous history
    + S8175384: SA: clhsdb 'printall' throws ClassCastException
    while printing out the bytecodes
    + S8176298: Log tags in -Xlog:help not sorted
    + S8179249: Improve process output analysis in CDS tests
    + S8182847: Copy class should use assert macros
    + S8184289: Obsolete -XX:+UnsyncloadClass and
  - XX:+MustCallLoadClassInternal options
    + S8186211: Negative tests for CONSTANT_Dynamic
    + S8186688: javax.lang.model.util.Elements.hides does not work
    correctly with interfaces
    + S8189330: Cleanup FileDescriptor implementation
    + S8190428: Minimal Dynamic Constant support for AArch64
    + S8191375: Add high-level jtreg VMProps to filter out CDS tests
    + S8193056: Title from build failure with Xcode 9.1
    + S8193150: Create a jtreg version of the test from JDK-8187143.
    + S8193373: Cleanup ElfFile and family
    + S8193846: Obsolete the VM option UseUTCFileTimestamp
    + S8193892: Impact of noncloneable MessageDigest implementation
    + S8193909: Obsolete(remove) Co-operative Memory Management (CMM)
    + S8194084: Obsolete FastTLABRefill and remove the related code
    + S8194691: Cleanup unnecessary casts in Atomic/OrderAccess uses
    + S8194994: Remove redundant string streams used for logging
    + S8195103: Refactor out card table from CardTableModRefBS to
    flatten the BarrierSet hierarchy
    + S8195112: x86 (32 bit): implementation for Thread-local
    handshakes
    + S8196308: Update tests AllLineLocations and ClassesByName to
    use TestScaffold instead of JDIScaffold.
    + S8196324: Update tests FilterMatch and FilterNoMatch to use
    TestScaffold.
    + S8196405: [REDO] NMT: add_committed_regions doesn't merge
    succeeding regions
    + S8196602: Change HeapRegionClosure to comply to naming
    conventions
    + S8196759: Move two java/text/Normalizer tests into OpenJDK
    + S8196783: Refactor LogTagLevelExpression into separate classes
    + S8196786: [PPC64+s390] ConstantDynamic support
    + S8196830: publicLookup().findVirtual should not return method
    handle to AccessibleObject.setAccessible
    + S8196880: VS2017 Addition of Global Delete Operator with Size
    Parameter Conflicts with Arena's Chunk Provided One
    + S8196884: VS2017 Multiple Type Cast Conversion Compilation
    Errors
    + S8196889: VS2017 Unable to Instantiate
    OrderAccess::release_store with an Incomplete Class Within an
    Inlined Method
    + S8196909: gcc 7.2.1 compiler warning in libdt_socket
    + S8196920: VerifierTest_1A.java and VerifierTest_1B.java fail:
    assert(receiver_klass->is_subtype_of(static_receiver_klass))
    failed: actual receiver must be subclass of static receiver
    klass
    + S8196930: [Testbug] serviceability/sa/ClhsdbFindPC.java fails
    to find expected output
    + S8196992: Resolve disabled warnings for libdt_socket
    + S8196997: VS2017 The non-Standard std::tr1 namespace and
    TR1-only machinery are deprecated and will be removed
    + S8197412: Enable docker container related tests for linux
    s390x
    + S8197454: Need Access decorator for storing oop into
    uninitialized location
    + S8197518: Kerberos krb5 authentication: AuthList's put method
    leads to performance issue
    + S8197563: assert(is_Loop()) crash in
    PhaseIdealLoop::try_move_store_before_loop()
    + S8197572: s390 build broken after 8165929
    + S8197589: Update CPU count algorithm when both cpu shares and
    quotas are used
    + S8197608: MacroAssembler::unimplemented calls global operator
    new[]
    + S8197772: metaspace uses global operator new/delete for gtest
    testing
    + S8197780: Null pointer dereference in
    Klass::is_instance_klass of klass.hpp:532
    + S8197789: os::SuspendedThreadTask causes references to global
    operator delete
    + S8197827: [windows] Small cleanups after JDK-8185712
    + S8197828: Null pointer dereference in
    MultiNode::proj_out_or_null
    + S8197857: fieldDescriptor prints incorrect 32-bit
    representation of compressed oops
    + S8197859: VS2017 Complains about UINTPTR_MAX definition in
    globalDefinitions_VisCPP.hpp
    + S8197868: VS2017 (C2065) 'timezone': Undeclared Identifier in
    share/runtime/os.cpp
    + S8197901: Crash during GC when logging level is debug
    + S8197906: Enable CDS mode execution of jtreg tests via make
    + S8197945: Qurarantine failing condy tests
    + S8197956: VS2017 (C4838) Narrowing conversion required from
    __int64 to julong
    + S8197968: [Backout] JDK-8196883
    G1RemSet::refine_card_concurrently doesn't need to check for
    cards in collection set
    + S8197992: Move the OopStorage::ParState type out of inline.hpp
    + S8197993: Remove last use of
    JavaThread::flush_barrier_queues()
    + S8197994: Move JavaThread::initialize_queues() logic to
    G1SATBCardTableLoggingModRefBS
    + S8197999: Accessors in typeArrayOopDesc should use new Access
    API
    + S8198225: os::attempt_reserve_memory_at records memory as
    committed
    + S8198249: Remove deprecated Runtime::runFinalizersOnExit and
    System::runFinalizersOnExit
    + S8198251: [Graal] compiler/intrinsics/bmi/verifycode tests
    fail with Graal on macos
    + S8198265: Make
    CollectorPolicy::satisfy_failed_metadata_allocation() virtual
    + S8198267: Allow GCId::current_raw() calls from
    non-NamedThreads
    + S8198268: Add time argument to
    ConcurrentGCTimer::register_gc_pause_start/_end
    + S8198269: Allow GCCauseSetter to be used outside of safepoints
    + S8198270: Remove dangerous assert in HandleArea::oops_do()
    + S8198271: Make CollectedHeap::create_heap_space_summary()
    virtual
    + S8198275: AIX build broken after latest whitebox.cpp changes
    + S8198286: Direct memory accessors in typeArrayOop.hpp should
    use Access API
    + S8198287: Cleanup ElfFile usage in whitebox.cpp
    + S8198311: Avoid uses of global malloc and free
    + S8198341: Build failures after 8194084 (Obsolete
    FastTLABRefill and remove the related code)
    + S8198369: Clean up GCId and GCIdMark
    + S8198373: Remove CollectorPolicy::is/as functions
    + S8198375: Passing 'null' value to lookup param of
    ConstantBootstraps.invoke does not throw NullPointerException
    + S8198420: Remove unused extension point AllocationContextStats
    + S8198439: Fix aarch64 code for handling generate_code_for
    after FastTLABFill obsolete code
    + S8198480: Improve ClassLoaders static init block
    + S8198481: Coding style cleanups for
    src/java.base/share/classes/jdk/internal/loader
    + S8198482: The URLClassPath field "urls" should be renamed to
    "unopenedUrls"
    + S8198484: URLClassPath should use an ArrayDeque instead of a
    Stack
    + S8198485: Simplify a URLClassPath constructor
    + S8198490: java/util/logging/TestLogConfigurationDeadLock.java
    timed out.
    + S8198492: Bootstrapping java.lang.invoke can cause deadlock
    after JDK-8198418
    + S8198507: Remove CollectorPolicy::create_rem_set
    + S8198509: Move satisfy_failed_metadata_allocation out from
    CollectorPolicy
    + S8198511: Move allocation functions from GenCollectorPolicy
    to GenCollectedHeap
    + S8198515: Extract SoftReferencePolicy code out of
    CollectorPolicy
    + S8198522: Javadoc search broken after output files
    organization for modules
    + S8198525: Move _size_policy out of GenCollectorPolicy into
    GenCollectedHeap
    + S8198528: Move GenerationSpecs from GenCollectorPolicy to
    GenCollectedHeap
    + S8198530: Move _gc_policy_counters from GenCollectorPolicy to
    GenCollectedHeap
    + S8198533: Remove obsolete JDIScaffold class from repo.
    + S8198539: Cleanup of unused imports in
    java/util/jar/Attributes.java (java.base) and
    JdpController.java (jdk.management.agent)
    + S8198551: Rename hotspot_tier1 test group to tier1
    + S8198553: jcmd: separate Metaspace statistics from NMT
    + S8198558: Windows does not build without precompiled headers
    + S8198560: Remove implicit casts from oop to JavaThread* and
    jlong*
    + S8198562: (ch) Separate blocking and non-blocking code paths
    (part 1)
    + S8198564: Multiple crashes on SPARC
    + S8198568: clean up test/hotspot/jtreg/ProblemList.txt
    + S8198569: SetupTextFileProcessing should use sed with 'g'
    + S8198573: JShell: class replace loses instances
    + S8198585: add asserts to verify that ServiceUtil::visible_oop
    is not needed
    + S8198627: JDK-8198318 broke readlink testing
    + S8198635: Remove unused safepoint message functions and
    ShowSafepointMsgs
    + S8198645: Use System.lineSeparator() instead of
    getProperty("line.separator")
    + S8198653: ClassLoader::getSystemClassLoader throws
    InternalError when called after shutdown
    + S8198656: Update copyright to 2018
    + S8198658: Docs still point to JDK 9 docs
    + S8198670: [testbug] Test
    jdk/internal/jline/extra/HistoryTest.java is broken after
    8166232
    + S8198726: Quarantine SADebugDTest.java again
    + S8198751: Refactor SetupNativeCompilation to take NAME and
    TYPE
    + S8198754: (ch) Separate blocking and non-blocking code paths
    (part 2)
    + S8198755: Reduce cost of
    InvokerBytecodeGenerator::isStaticallyInvocable/-Nameable
    + S8198808: jdi tests failing after JDK-8198484
    + S8198820: Problem list tools/jimage/JImageExtractTest.java
    + S8198831: Lazy initialization of ValueConversions
    MethodHandles
- Modified patch:
  * system-pcsclite.patch
    + Fix merge error in the patch
* Mon Feb 26 2018 fstrba@suse.com
- Update to upstream tag jdk-11+2
  * Fixes:
    + S8058965: Remove IPv6 support from TwoStacksPlainSocketImpl
    [win]
    + S8153294: Solaris devkit uses linker from system instead of
    in devkit
    + S8170120: jimage throws IOException when the given file is
    not a jimage file
    + S8176474: test/jdk/jshell/JdiBogusHostListenExecutionControlTest.java
    fails with java.net.BindException
    + S8190904: Incorrect currency instance returned by
    java.util.Currency.getInstance()
    + S8194154: System property user.dir should not be changed
    + S8194892: add compiler support for local-variable syntax for
    lambda parameters
    + S8194922: jlink --exclude-resources should never exclude
    module-info.class
    + S8196959: NullPointerException in discovery003.java
    + S8197439: Crash with -XDfind=lambda for anonymous class in
    anonymous class.
    + S8197812: (ref) Data race in Finalizer
    + S8198227: Fix COMPARE_BUILD after forest consolidation
    + S8198228: Spec clarification: j.u.Locale.getDisplayName()
    + S8198301: jdk11+1 was built as 'fcs' instead of 'ea'
    + S8198303: jdk11+1 was build with incorrect GA date as
    2018-03-20
    + S8198306: Add post custom extension hooks to two launchers
    + S8198318: Make build comparisons clean again
    + S8198328: Create devkit for Solaris with developer studio
    12.6 and Solaris11.3
    + S8198379: tools/jimage/JImageListTest.java failing
    + S8198380: tools/jimage/JImageExtractTest.java failing
    + S8198385: Remove property sun.locale.formatasdefault
    + S8198417: Exclude tools/jimage/JImageExtractTest.java and
    tools/jimage/JImageListTest.java on Windows
    + S8198418: Invoke LambdaMetafactory::metafactory exactly from
    the BootstrapMethodInvoker
    + S8198425: make/Main.gmk Add extra extension/override points
    to the make file
    + S8198441: Replace native Runtime::runFinalization0 method
    with shared secrets
    + S8198450: Make jdk.internal.vm.compiler/module-info.java.extra
    reproducable
    + S8198479: JDK build is broken by 8194892
    + S8198502: Exception at runtime due to lambda analyzer
    reattributes live AST
    + S8198512: compiler support for local-variable syntax for
    lambda parameters
    + S8198523: Refactor BootstrapMethodInvoker to further avoid
    runtime type checks
    + S8198563: Test langtools/tools/javac/analyzer/AnonymousInAnonymous.java
    failing after JDK-8198502
* Mon Feb 19 2018 fstrba@suse.com
- Update to upstream tag jdk-11+1
- Removed patches:
  * JDK-8194739-zero.patch
  * aarch64-form_address.patch
    + Integrated upstream
- Modified patch:
  * system-pcsclite.patch
    + Rediff to changed context
* Mon Jan 29 2018 fstrba@suse.com
- Added patch:
  * aarch64-form_address.patch
  - Fix crash due to mistake in committed patch for JDK-8195859
* Fri Jan 26 2018 fstrba@suse.com
- Upgrade to the tip of jdk repository of January 26th, 2018
- Modified patches:
  * disable-doclint-by-default.patch
  * jdk10-gcc6.patch
    + Rediffed to a changed context
- Removed patches:
  * java-10-openjdk-linuxfilestore.patch
  * remove_javah_for_real.patch
    + Integrated upstream
- Added patch:
  * JDK-8194739-zero.patch
    + S8194739: Zero port of 8174962: Better interface invocations
* Tue Jan 16 2018 fstrba@suse.com
- Recommend tzdata-java8 instead of depending on it. This fixes
  build cycles.
* Fri Dec 15 2017 fstrba@suse.com
- Initial package of jdk-11+0
  * java-11-openjdk technology preview
